@@ -657,7 +657,7 @@ boolean pconx_convert_value_data(weed_plant_t *inst, int pnum, weed_plant_t *dpa
     nmin=weed_leaf_num_elements(dptmpl,"min");
   }
 
-  g_print("got %d and %d\n",stype,dtype);
+  //g_print("got %d and %d\n",stype,dtype);
 
   switch (stype) {
   case WEED_SEED_STRING:
@@ -1821,7 +1821,7 @@ boolean cconx_convert_pixel_data(weed_plant_t *dchan, weed_plant_t *schan) {
 
   weed_plant_t *dtmpl=weed_get_plantptr_value(dchan,"template",&error);
 
-  void *spdata,*dpdata;
+  uint8_t *spdata,*dpdata;
 
   register int i;
 
@@ -1837,7 +1837,7 @@ boolean cconx_convert_pixel_data(weed_plant_t *dchan, weed_plant_t *schan) {
   opal=weed_get_int_value(dchan,"current_palette",&error);
   orow=weed_get_int_value(dchan,"rowstrides",&error);
 
-  spdata=weed_get_voidptr_value(schan,"pixel_data",&error);
+  spdata=(uint8_t *)weed_get_voidptr_value(schan,"pixel_data",&error);
 
   if (ipal==opal&&iwidth==owidth&&iheight==oheight&&irow==orow) {
     /// everything matches - we can just do a steal
@@ -1860,7 +1860,7 @@ boolean cconx_convert_pixel_data(weed_plant_t *dchan, weed_plant_t *schan) {
     weed_free(palettes);
   }
 
-  dpdata=weed_get_voidptr_value(dchan,"pixel_data",&error);
+  dpdata=(uint8_t *)weed_get_voidptr_value(dchan,"pixel_data",&error);
 
   if (dpdata!=NULL) {
     g_free(dpdata);
@@ -1872,7 +1872,7 @@ boolean cconx_convert_pixel_data(weed_plant_t *dchan, weed_plant_t *schan) {
   weed_set_int_value(dchan,"current_palette",ipal);
 
   if (pal_ok) {
-    weed_set_voidptr_value(dchan,"pixel_data",spdata);
+    weed_set_voidptr_value(dchan,"pixel_data",(void *)spdata);
     weed_set_int_value(dchan,"rowstrides",irow);
     
     /// caller - do not free in dchan
@@ -1880,17 +1880,17 @@ boolean cconx_convert_pixel_data(weed_plant_t *dchan, weed_plant_t *schan) {
     return FALSE;
   }
   create_empty_pixel_data(dchan,FALSE,TRUE);
-  dpdata=weed_get_voidptr_value(dchan,"pixel_data",&error);
+  dpdata=(uint8_t *)weed_get_voidptr_value(dchan,"pixel_data",&error);
   
   orow=weed_get_int_value(dchan,"rowstrides",&error);
 
   if (irow==orow) {
-    memcpy(dpdata,spdata,irow*iheight);
+    memcpy((void *)dpdata,(void *)spdata,irow*iheight);
   }
   else {
     int ipwidth = iwidth * weed_palette_get_bits_per_macropixel(ipal) / 8;
     for (i=0;i<iheight;i++) {
-      memcpy(dpdata,spdata,ipwidth);
+      memcpy((void *)dpdata,(void *)spdata,ipwidth);
       spdata+=irow;
       dpdata+=orow;
     }
@@ -2067,7 +2067,7 @@ static void apbutton_clicked(GtkButton *button, gpointer user_data) {
       model=gtk_combo_box_get_model(GTK_COMBO_BOX(conxwp->pfxcombo[k]));
       gtk_tree_model_get_iter(model,&iter,tpath);
       gtk_combo_box_set_active_iter(LIVES_COMBO(conxwp->pfxcombo[k]),&iter);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
     }
     gtk_combo_box_set_active(LIVES_COMBO(conxwp->pcombo[k++]),i);
 
@@ -2137,7 +2137,7 @@ static void acbutton_clicked(GtkButton *button, gpointer user_data) {
       model=gtk_combo_box_get_model(GTK_COMBO_BOX(conxwp->cfxcombo[k]));
       gtk_tree_model_get_iter(model,&iter,tpath);
       gtk_combo_box_set_active_iter(LIVES_COMBO(conxwp->cfxcombo[k]),&iter);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
     }
     gtk_combo_box_set_active(LIVES_COMBO(conxwp->ccombo[k++]),i);
     if (k>=conxwp->num_alpha) break;
@@ -2704,7 +2704,7 @@ static void on_acheck_toggled(GtkToggleButton *acheck, gpointer user_data) {
 }
 
 
-GtkTreeModel *inparam_fx_model (boolean is_chans) {
+static LiVESTreeModel *inparam_fx_model (boolean is_chans) {
   GtkTreeStore *tstore;
 
   GtkTreeIter iter1,iter2;
@@ -2770,7 +2770,7 @@ GtkTreeModel *inparam_fx_model (boolean is_chans) {
 
   }
 
-  return (GtkTreeModel *)tstore;
+  return (LiVESTreeModel *)tstore;
 }
 
 
@@ -2778,10 +2778,9 @@ GtkTreeModel *inparam_fx_model (boolean is_chans) {
 
 
 static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
-  GtkTreeModel *model;
+  LiVESTreeModel *model;
 
   GtkWidget *label;
-  GtkWidget *hseparator;
   GtkWidget *top_vbox;
   GtkWidget *hbox,*hbox2;
   GtkWidget *scrolledwindow;
@@ -2814,20 +2813,9 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
 
   lctext=g_strdup(_("Connected to -->"));
 
-  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_show (scrolledwindow);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  top_vbox=lives_vbox_new (FALSE, 0);
 
-  top_vbox=gtk_vbox_new (FALSE, 0);
-
-    
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), top_vbox);
-
-   if (palette->style&STYLE_1) {
-    gtk_widget_modify_bg(lives_bin_get_child (LIVES_BIN (scrolledwindow)), GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  //gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (scrolledwindow))),GTK_SHADOW_IN);
+  scrolledwindow = lives_standard_scrolled_window_new (-1,-1,top_vbox);
 
   if (conxwp->num_alpha>0) {
     weed_plant_t **ochans=weed_get_plantptr_array(filter,"out_channel_templates",&error);
@@ -2839,42 +2827,37 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
     conxwp->ccombo=(GtkWidget **)g_malloc(conxwp->num_alpha*sizeof(GtkWidget *));
 
     label=lives_standard_label_new(_("Alpha Channel Connections"));
-    gtk_box_pack_start (GTK_BOX (top_vbox), label, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (top_vbox), label, FALSE, FALSE, widget_opts.packing_height);
 
     for (i=0;i<conxwp->num_alpha;i++) {
       chan=ochans[j++];
 
       if (!has_alpha_palette(chan)) continue;
 
-      hbox=gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, 10);
+      hbox=lives_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, widget_opts.packing_width);
 
       channame=weed_get_string_value(chan,"name",&error);
       label=lives_standard_label_new(channame);
-      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
       weed_free(channame);
 
       label=lives_standard_label_new(lctext);
-      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
 
 
       // create combo entry model
       model=inparam_fx_model(TRUE);
 
-#if GTK_CHECK_VERSION(2,24,0)
-      conxwp->cfxcombo[x] = gtk_combo_box_new_with_model_and_entry (model);
-#else
-      conxwp->cfxcombo[x] = gtk_combo_box_entry_new ();
-      gtk_combo_box_set_model(GTK_COMBO_BOX(conxwp->cfxcombo[x]),model);
-#endif
+      conxwp->cfxcombo[x] = lives_combo_new_with_model (model);
 
       lives_combo_set_entry_text_column(LIVES_COMBO(conxwp->cfxcombo[x]),NAME_COLUMN);
 
-      gtk_box_pack_start (GTK_BOX (hbox), conxwp->cfxcombo[x], FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), conxwp->cfxcombo[x], FALSE, FALSE, widget_opts.packing_width);
 
       fx_entry = lives_combo_get_entry(LIVES_COMBO(conxwp->cfxcombo[x]));
       gtk_entry_set_text (GTK_ENTRY (fx_entry),mainw->string_constants[LIVES_STRING_CONSTANT_NONE]);
-      gtk_entry_set_editable (GTK_ENTRY (fx_entry), FALSE);
+      lives_entry_set_editable (LIVES_ENTRY (fx_entry), FALSE);
 
 
       conxwp->ccombo[x]=lives_standard_combo_new("",FALSE,NULL,LIVES_BOX(hbox),NULL);
@@ -2895,9 +2878,7 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
   }
 
   if (conxwp->num_alpha>0&&conxwp->num_params>0) {
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (top_vbox), hseparator, FALSE, FALSE, 10);
+    add_hsep_to_box (LIVES_BOX (top_vbox));
   }
 
 
@@ -2914,12 +2895,12 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
     x=0;
 
     label=lives_standard_label_new(_("Parameter Data Connections"));
-    gtk_box_pack_start (GTK_BOX (top_vbox), label, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (top_vbox), label, FALSE, FALSE, widget_opts.packing_height);
 
-    hbox=gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, 10);
-    hbox2=gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_end (GTK_BOX (hbox), hbox2, FALSE, FALSE, 10);
+    hbox=lives_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+    hbox2=lives_hbox_new (FALSE, 0);
+    gtk_box_pack_end (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
     conxwp->allcheckc=lives_standard_check_button_new(_("Autoscale All"),FALSE,LIVES_BOX(hbox2),NULL);
 
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(conxwp->allcheckc),TRUE);
@@ -2929,8 +2910,8 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
 			    (gpointer)conxwp);
 
     for (i=0;i<conxwp->num_params;i++) {
-      hbox=gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, 10);
+      hbox=lives_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (top_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
       param=oparams[i];
 
@@ -2962,29 +2943,24 @@ static GtkWidget *conx_scroll_new(weed_plant_t *filter, lives_conx_w *conxwp) {
       text=g_strdup_printf("%s (%s%s) %s",pname,ptype,array_type,range);
 
       label=lives_standard_label_new(text);
-      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
       weed_free(pname); g_free(ptype); g_free(array_type); g_free(range); g_free(text);
 
       label=lives_standard_label_new(lctext);
-      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
 
       // create combo entry model
       model=inparam_fx_model(FALSE);
 
-#if GTK_CHECK_VERSION(2,24,0)
-      conxwp->pfxcombo[x] = gtk_combo_box_new_with_model_and_entry (model);
-#else
-      conxwp->pfxcombo[x] = gtk_combo_box_entry_new ();
-      gtk_combo_box_set_model(GTK_COMBO_BOX(conxwp->pfxcombo[x]),model);
-#endif
+      conxwp->pfxcombo[x] = lives_combo_new_with_model (model);
 
       lives_combo_set_entry_text_column(LIVES_COMBO(conxwp->pfxcombo[x]),NAME_COLUMN);
 
-      gtk_box_pack_start (GTK_BOX (hbox), conxwp->pfxcombo[x], FALSE, FALSE, 10);
+      gtk_box_pack_start (GTK_BOX (hbox), conxwp->pfxcombo[x], FALSE, FALSE, widget_opts.packing_width);
 
       fx_entry = lives_combo_get_entry(LIVES_COMBO(conxwp->pfxcombo[x]));
       gtk_entry_set_text (GTK_ENTRY (fx_entry),mainw->string_constants[LIVES_STRING_CONSTANT_NONE]);
-      gtk_entry_set_editable (GTK_ENTRY (fx_entry), FALSE);
+      lives_entry_set_editable (LIVES_ENTRY (fx_entry), FALSE);
 
 
       conxwp->pcombo[x]=lives_standard_combo_new("",FALSE,NULL,LIVES_BOX(hbox),NULL);
@@ -3319,21 +3295,23 @@ static boolean show_existing(lives_conx_w *conxwp) {
 GtkWidget *make_datacon_window(int key, int mode) {
   weed_plant_t *filter=rte_keymode_get_filter(key+1,mode);
 
+  static lives_conx_w conxw;
+
   GtkWidget *cbox,*abox;
   GtkWidget *scrolledwindow;
 
   GtkWidget *cancelbutton;
   GtkWidget *okbutton;
 
+  GtkAccelGroup *accel_group;
+
+  boolean needsanother=TRUE;
+
   int scr_width,scr_height;
 
   int winsize_h;
   int winsize_v;
 
-  boolean needsanother=TRUE;
-
-  static lives_conx_w conxw;
-
   if (filter==NULL) return NULL;
 
   acbutton=apbutton=NULL;
@@ -3364,13 +3342,14 @@ GtkWidget *make_datacon_window(int key, int mode) {
   conxw.conx_dialog=lives_standard_dialog_new(_("LiVES: - Parameter and Alpha Channel Connections"),FALSE);
   gtk_widget_set_size_request (conxw.conx_dialog, winsize_h, winsize_v);
 
-
+  accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+  gtk_window_add_accel_group (GTK_WINDOW (conxw.conx_dialog), accel_group);
 
   abox = lives_dialog_get_action_area(LIVES_DIALOG(conxw.conx_dialog));
 
   if (conxw.num_alpha>0) {
     acbutton = gtk_button_new_with_mnemonic (_("Auto Connect Channels"));
-    gtk_box_pack_start (GTK_BOX (abox), acbutton, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (abox), acbutton, FALSE, FALSE, widget_opts.packing_width);
     gtk_widget_set_sensitive(acbutton,FALSE);
 
     g_signal_connect (GTK_OBJECT (acbutton), "clicked",
@@ -3382,7 +3361,7 @@ GtkWidget *make_datacon_window(int key, int mode) {
 
   if (conxw.num_params>0) {
     apbutton = gtk_button_new_with_mnemonic (_("Auto Connect Parameters"));
-    gtk_box_pack_start (GTK_BOX (abox), apbutton, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (abox), apbutton, FALSE, FALSE, widget_opts.packing_width);
     gtk_widget_set_sensitive(apbutton,FALSE);
 
     g_signal_connect (GTK_OBJECT (apbutton), "clicked",
@@ -3392,7 +3371,7 @@ GtkWidget *make_datacon_window(int key, int mode) {
   }
 
   disconbutton = gtk_button_new_with_mnemonic (_("Disconnect All"));
-  gtk_box_pack_start (GTK_BOX (abox), disconbutton, FALSE, FALSE, 10);
+  gtk_box_pack_start (GTK_BOX (abox), disconbutton, FALSE, FALSE, widget_opts.packing_width);
   gtk_widget_set_sensitive(disconbutton,FALSE);
 
   g_signal_connect (GTK_OBJECT (disconbutton), "clicked",
@@ -3422,6 +3401,9 @@ GtkWidget *make_datacon_window(int key, int mode) {
   lives_widget_set_can_focus_and_default (okbutton);
   gtk_widget_grab_default(okbutton);
 
+  gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+                              LIVES_KEY_Escape,  (GdkModifierType)0, (GtkAccelFlags)0);
+
 
   g_signal_connect (GTK_OBJECT (cancelbutton), "clicked",
 		    G_CALLBACK (conxw_cancel_clicked),
