@@ -49,7 +49,7 @@ static boolean apply_audio_fx;
 // generic
 
 
-gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, gboolean plural) {
+gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, boolean plural) {
 
   // return value should be free'd after use
   switch (cat) {
@@ -142,31 +142,31 @@ gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, gboolean plural) {
 // Rendered effects
 
 
-gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
+boolean do_effect(lives_rfx_t *rfx, boolean is_preview) {
   // returns FALSE if the user cancelled
   // leave_info_file is set if a preview turned into actual processing: ie. no params were changed after the preview
   // preview generates .pre files instead of .mgk, so needs special post-processing
 
-  gint oundo_start=cfile->undo_start;
-  gint oundo_end=cfile->undo_end;
+  int oundo_start=cfile->undo_start;
+  int oundo_end=cfile->undo_end;
   gchar effectstring[128];
-  gdouble old_pb_fps=cfile->pb_fps;
+  double old_pb_fps=cfile->pb_fps;
 
   gchar *text;
   gchar *fxcommand=NULL,*cmd;
-  gint current_file=mainw->current_file;
+  int current_file=mainw->current_file;
 
-  gint new_file=current_file;
-  gint ldfile;
+  int new_file=current_file;
+  int ldfile;
 
-  gboolean got_no_frames=FALSE;
+  boolean got_no_frames=FALSE;
   gchar *tmp;
 
   if (rfx->num_in_channels==0&&!is_preview) current_file=mainw->pre_src_file;
 
   if (is_preview) {
     // generators start at 1, even though they have no initial frames
-    cfile->progress_start=cfile->undo_start=cfile->start+(rfx->num_in_channels==0?1:0);
+    cfile->progress_start=cfile->undo_start=rfx->num_in_channels==0?1:cfile->start;
     cfile->progress_end=cfile->undo_end=cfile->end;
   }
   else if (rfx->num_in_channels!=2) {
@@ -186,12 +186,12 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
       // transition has a few extra bits
       pdefault=g_strdup_printf ("%s %d %d %d %d %d %s %s %d \"%s/%s\"",cfile->handle,rfx->status,
 				cfile->progress_start,cfile->progress_end,cfile->hsize,cfile->vsize,
-				cfile->img_type==IMG_TYPE_JPEG?"jpg":"png",clipboard->img_type==IMG_TYPE_JPEG?
-				"jpg":"png",clipboard->start,prefs->tmpdir,clipboard->handle);
+				get_image_ext_for_type(cfile->img_type),get_image_ext_for_type(clipboard->img_type),
+				clipboard->start,prefs->tmpdir,clipboard->handle);
     }
     else {
       pdefault=g_strdup_printf ("%s %d %d %d %d %d %s",cfile->handle,rfx->status,cfile->progress_start,
-				cfile->progress_end,cfile->hsize,cfile->vsize,cfile->img_type==IMG_TYPE_JPEG?"jpg":"png");
+				cfile->progress_end,cfile->hsize,cfile->vsize,get_image_ext_for_type(cfile->img_type));
     }
     // and append params
     if (is_preview) {
@@ -392,7 +392,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
   if (rfx->props&RFX_PROPS_MAY_RESIZE||rfx->num_in_channels==0) {
     // get new frame size
     if (rfx->status!=RFX_STATUS_WEED) { 
-      gint numtok=get_token_count (mainw->msg,'|');
+      int numtok=get_token_count (mainw->msg,'|');
       
       if (numtok>1) {
 	gchar **array=g_strsplit(mainw->msg,"|",numtok);
@@ -423,7 +423,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
     if (rfx->num_in_channels>0) {
       if (cfile->hsize==cfile->ohsize&&cfile->vsize==cfile->ovsize) cfile->undo_action=UNDO_EFFECT;
       else {
-	gboolean bad_header=FALSE;
+	boolean bad_header=FALSE;
 	save_clip_value(mainw->current_file,CLIP_DETAILS_WIDTH,&cfile->hsize);
 	if (mainw->com_failed||mainw->write_failed) bad_header=TRUE;
 	save_clip_value(mainw->current_file,CLIP_DETAILS_HEIGHT,&cfile->vsize);
@@ -440,7 +440,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
   if (mainw->keep_pre) {
     // this comes from a preview which then turned into processing
     gchar *com=g_strdup_printf("%s mv_pre \"%s\" %d %d \"%s\"",prefs->backend_sync, cfile->handle,cfile->progress_start,
-			       cfile->progress_end,cfile->img_type==IMG_TYPE_JPEG?"jpg":"png");
+			       cfile->progress_end,get_image_ext_for_type(cfile->img_type));
 
     unlink(cfile->info_file);
     mainw->cancelled=CANCEL_NONE;
@@ -452,7 +452,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
 
     if (mainw->error) {
       if (!mainw->cancelled) {
-	do_error_dialog(_("\nNo frames were generated.\n"));
+	do_info_dialog(_("\nNo frames were generated.\n"));
 	d_print_failed();
       }
       else if (mainw->cancelled!=CANCEL_ERROR) d_print_cancelled();
@@ -483,7 +483,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
     if (rfx->props&RFX_PROPS_BATCHG) {
       // batch mode generators need some extra processing
       gchar *imgdir=g_strdup_printf("%s%s",prefs->tmpdir,cfile->handle);
-      gint img_file=mainw->current_file;
+      int img_file=mainw->current_file;
       
       mainw->suppress_dprint=TRUE;
       open_file_sel(imgdir,0,0);
@@ -519,7 +519,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
     if (got_no_frames||cfile->frames==0) {
       mainw->is_generating=FALSE;
       if (!mainw->cancelled) {
-	do_error_dialog(_("\nNo frames were generated.\n"));
+	do_info_dialog(_("\nNo frames were generated.\n"));
 	d_print_failed();
       }
       else d_print_cancelled();
@@ -608,7 +608,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
 
   
 
-lives_render_error_t realfx_progress (gboolean reset) {
+lives_render_error_t realfx_progress (boolean reset) {
   static int i;
   GError *error=NULL;
   gchar oname[PATH_MAX];
@@ -647,10 +647,12 @@ lives_render_error_t realfx_progress (gboolean reset) {
       mainw->internal_messaging=FALSE;
       g_snprintf(mainw->msg,9,"completed");
     }
+    mainw->rowstride_alignment_hint=1;
     return LIVES_RENDER_COMPLETE;
   }
 
   if (has_video_filters(FALSE)||resize_instance!=NULL) {
+    mainw->rowstride_alignment=mainw->rowstride_alignment_hint;
 
     layer=weed_plant_new(WEED_PLANT_CHANNEL);
     weed_set_int_value(layer,"clip",mainw->current_file);
@@ -658,7 +660,7 @@ lives_render_error_t realfx_progress (gboolean reset) {
 
     frameticks=(i-cfile->start+1.)/cfile->fps*U_SECL;
 
-    if (!pull_frame(layer,cfile->img_type==IMG_TYPE_JPEG?"jpg":"png",frameticks)) {
+    if (!pull_frame(layer,get_image_ext_for_type(cfile->img_type),frameticks)) {
       // do_read_failed_error_s() cannot be used here as we dont know the filename
       g_snprintf (mainw->msg,256,"error|missing image %d",i);
       return LIVES_RENDER_WARNING_READ_FRAME;
@@ -669,12 +671,17 @@ lives_render_error_t realfx_progress (gboolean reset) {
     if (!has_video_filters(TRUE)||resize_instance!=NULL) {
       layer_palette=weed_get_int_value(layer,"current_palette",&weed_error);
 
-      if (cfile->img_type==IMG_TYPE_JPEG&&layer_palette!=WEED_PALETTE_RGB24&&layer_palette!=WEED_PALETTE_RGBA32) 
+      if (resize_instance==NULL) resize_layer(layer,cfile->hsize,cfile->vsize,LIVES_INTERP_BEST,layer_palette,0);
+
+      if (cfile->img_type==IMG_TYPE_JPEG&&layer_palette!=WEED_PALETTE_RGB24&&layer_palette!=WEED_PALETTE_RGBA32) {
 	convert_layer_palette(layer,WEED_PALETTE_RGB24,0);
-      else if (cfile->img_type==IMG_TYPE_PNG&&layer_palette!=WEED_PALETTE_RGBA32) 
+	layer_palette=WEED_PALETTE_RGB24;
+      }
+      else if (cfile->img_type==IMG_TYPE_PNG&&layer_palette!=WEED_PALETTE_RGBA32) {
 	convert_layer_palette(layer,WEED_PALETTE_RGBA32,0);
+	layer_palette=WEED_PALETTE_RGBA32;
+      }
       
-      if (resize_instance==NULL) resize_layer(layer,cfile->hsize,cfile->vsize,LIVES_INTERP_BEST);
       pixbuf=layer_to_pixbuf(layer);
       weed_plant_free(layer);
       
@@ -712,7 +719,7 @@ lives_render_error_t realfx_progress (gboolean reset) {
       mainw->error=FALSE;
       mainw->cancelled=CANCEL_NONE;
       com=g_strdup_printf ("%s mv_mgk \"%s\" %d %d \"%s\"",prefs->backend,cfile->handle,cfile->start,
-			   cfile->end,cfile->img_type==IMG_TYPE_JPEG?"jpg":"png");
+			   cfile->end,get_image_ext_for_type(cfile->img_type));
       lives_system (com,FALSE);
       g_free (com);
       mainw->internal_messaging=FALSE;
@@ -725,11 +732,13 @@ lives_render_error_t realfx_progress (gboolean reset) {
 	if (cfile->clip_type==CLIP_TYPE_FILE) {
 	  if (!check_if_non_virtual(mainw->current_file,1,cfile->frames)) save_frame_index(mainw->current_file);
 	}
+	mainw->rowstride_alignment_hint=1;
 	return LIVES_RENDER_COMPLETE;
       }
     }
     else {
       sprintf(mainw->msg,"%s","completed");
+      mainw->rowstride_alignment_hint=1;
       return LIVES_RENDER_COMPLETE;
     }
   }
@@ -740,10 +749,10 @@ lives_render_error_t realfx_progress (gboolean reset) {
 
 
 
-gboolean on_realfx_activate_inner(gint type, lives_rfx_t *rfx) {
+boolean on_realfx_activate_inner(int type, lives_rfx_t *rfx) {
   // type can be 0 - apply current realtime effects
   // 1 - resize (using weed filter)
-  gboolean retval;
+  boolean retval;
 
   boolean has_new_audio=FALSE;
 
@@ -753,7 +762,7 @@ gboolean on_realfx_activate_inner(gint type, lives_rfx_t *rfx) {
     if (mainw->agen_key!=0&&cfile->achans==0) {
       // apply audio gen to clip with no audio - prompt for audio settings
       resaudw=create_resaudw(2,NULL,NULL);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
       gdk_window_raise(lives_widget_get_xwindow(resaudw->dialog));
 
       if (gtk_dialog_run(GTK_DIALOG(resaudw->dialog))!=GTK_RESPONSE_OK) return FALSE;
@@ -773,7 +782,9 @@ gboolean on_realfx_activate_inner(gint type, lives_rfx_t *rfx) {
 
   mainw->internal_messaging=TRUE;
   framecount=0;
- 
+
+  mainw->rowstride_alignment_hint=1;
+
   mainw->progress_fn=&realfx_progress;
   mainw->progress_fn (TRUE);
 
@@ -816,7 +827,7 @@ gboolean on_realfx_activate_inner(gint type, lives_rfx_t *rfx) {
 
 
 void on_realfx_activate (GtkMenuItem *menuitem, gpointer user_data) {
-  gint type=1;
+  int type=1;
 
   boolean has_lmap_error=FALSE;
 
@@ -997,14 +1008,14 @@ weed_plant_t *get_blend_layer(weed_timecode_t tc) {
   
   blend_file->last_frameno=blend_file->frameno;
 
-  blend_file->frameno=calc_new_playback_position(mainw->blend_file,blend_tc,&ntc);
+  blend_file->frameno=calc_new_playback_position(mainw->blend_file,blend_tc,(uint64_t *)&ntc);
 
   blend_tc=ntc;
 
   layer=weed_plant_new(WEED_PLANT_CHANNEL);
   weed_set_int_value(layer,"clip",mainw->blend_file);
   weed_set_int_value(layer,"frame",blend_file->frameno);
-  if (!pull_frame(layer,blend_file->img_type==IMG_TYPE_JPEG?"jpg":"png",tc)) {
+  if (!pull_frame(layer,get_image_ext_for_type(blend_file->img_type),tc)) {
     weed_plant_free(layer);
     layer=NULL;
   }
@@ -1019,7 +1030,7 @@ weed_plant_t *get_blend_layer(weed_timecode_t tc) {
 
 
 
-gboolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+boolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
 // this is the callback which happens when a rte is keyed
   gint key=GPOINTER_TO_INT(user_data);
   guint new_rte=GU641<<(key-1);
@@ -1075,13 +1086,13 @@ gboolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval,
 
 
 
-gboolean rte_on_off_callback_hook (GtkToggleButton *button, gpointer user_data) {
+boolean rte_on_off_callback_hook (GtkToggleButton *button, gpointer user_data) {
   rte_on_off_callback (NULL, NULL, 0, (GdkModifierType)0, user_data);
   return TRUE;
 }
 
 
-gboolean grabkeys_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+boolean grabkeys_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
   // assign the keys to the last key-grabable effect 
   mainw->rte_keys=mainw->last_grabable_effect;
   mainw->osc_block=TRUE;
@@ -1095,7 +1106,7 @@ gboolean grabkeys_callback (GtkAccelGroup *group, GObject *obj, guint keyval, Gd
 
 
 
-gboolean textparm_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+boolean textparm_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
   // keyboard linked to first string parameter, until TAB is pressed
   mainw->rte_textparm=get_textparm();
   return TRUE;
@@ -1103,7 +1114,7 @@ gboolean textparm_callback (GtkAccelGroup *group, GObject *obj, guint keyval, Gd
 
 
 
-gboolean grabkeys_callback_hook (GtkToggleButton *button, gpointer user_data) {
+boolean grabkeys_callback_hook (GtkToggleButton *button, gpointer user_data) {
   if (!lives_toggle_button_get_active(button)) return TRUE;
   mainw->last_grabable_effect=GPOINTER_TO_INT(user_data);
   grabkeys_callback (NULL, NULL, 0, (GdkModifierType)0, user_data);
@@ -1111,7 +1122,7 @@ gboolean grabkeys_callback_hook (GtkToggleButton *button, gpointer user_data) {
 }
 
 
-gboolean rtemode_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+boolean rtemode_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
   if (mainw->rte_keys==-1) return TRUE;
   rte_key_setmode(0,-1);
   mainw->blend_factor=weed_get_blend_factor(mainw->rte_keys);
@@ -1119,11 +1130,11 @@ gboolean rtemode_callback (GtkAccelGroup *group, GObject *obj, guint keyval, Gdk
 }
 
 
-gboolean rtemode_callback_hook (GtkToggleButton *button, gpointer user_data) {
+boolean rtemode_callback_hook (GtkToggleButton *button, gpointer user_data) {
   gint key_mode=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
-  gint key=(gint)(key_mode/modes);
-  gint mode=key_mode-key*modes;
+  int key=(int)(key_mode/modes);
+  int mode=key_mode-key*modes;
 
   if (!lives_toggle_button_get_active(button)) return TRUE;
 
@@ -1132,8 +1143,8 @@ gboolean rtemode_callback_hook (GtkToggleButton *button, gpointer user_data) {
 }
 
 
-gboolean swap_fg_bg_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
-  gint old_file=mainw->current_file;
+boolean swap_fg_bg_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+  int old_file=mainw->current_file;
 
   if (mainw->playing_file<1||mainw->num_tr_applied==0||mainw->noswitch||mainw->blend_file==-1||
       mainw->blend_file==mainw->current_file||mainw->files[mainw->blend_file]==NULL||mainw->preview||
