@@ -1,6 +1,6 @@
 // yuv4mpeg.c
 // LiVES
-// (c) G. Finch 2004 - 2013 <salsaman@xs4all.nl,salsaman@gmail.com>
+// (c) G. Finch 2004 - 2013 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -132,7 +132,7 @@ static gboolean lives_yuv_stream_start_read (file *sfile) {
     while (ntime<YUV4_O_TIME&&!pthread_kill(y4thread,0)) {
       // wait for thread to complete or timeout
       g_usleep(prefs->sleep_time);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
       
       gettimeofday(&otv, NULL);
       ntime=(otv.tv_sec*1000000+otv.tv_usec-stime);
@@ -170,7 +170,7 @@ static gboolean lives_yuv_stream_start_read (file *sfile) {
   while (ntime<YUV4_H_TIME&&!pthread_kill(y4thread,0)) {
     // wait for thread to complete or timeout
     g_usleep(prefs->sleep_time);
-    while (g_main_context_iteration(NULL,FALSE));
+    lives_widget_context_update();
 
     gettimeofday(&otv, NULL);
     ntime=(otv.tv_sec*1000000+otv.tv_usec-stime);
@@ -400,17 +400,12 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
     d_print (_ ("none\n"));
   }
   else {
-    d_print ((tmp=g_strdup_printf(_ ("%d Hz %d channel(s) %d bps\n"),cfile->arate,cfile->achans,cfile->asampsize)));
+    d_print ((tmp=g_strdup_printf(P_("%d Hz %d channel %d bps\n","%d Hz %d channels %d bps\n",cfile->achans),cfile->arate,cfile->achans,cfile->asampsize)));
     g_free(tmp);
   }
 
   // if not playing, start playing
   if (mainw->playing_file==-1) {
-    if (mainw->play_window!=NULL&&old_file==-1) {
-      // usually preview or load_preview_frame would do this
-      g_signal_handler_block(mainw->play_window,mainw->pw_exp_func);
-      mainw->pw_exp_is_blocked=TRUE;
-    }
 
     // temp kludge, symlink audiodump.pcm to wav file, then pretend we are playing
     // an opening preview . Doesn't work with fifo.
