@@ -1,6 +1,6 @@
 // merge.c
 // LiVES (lives-exe)
-// (c) G. Finch 2003 - 2012 (salsaman@gmail.com)
+// (c) G. Finch 2003 - 2013 (salsaman@gmail.com)
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -21,29 +21,35 @@
 _merge_opts* merge_opts;
 
 void create_merge_dialog (void) {
+  lives_rfx_t *rfx;
+
   GtkWidget *dialog_vbox;
   GtkWidget *vbox;
-  GSList *radiobutton_align_group = NULL;
-  GSList *radiobutton_insdrop_group = NULL;
   GtkWidget *align_start_button;
   GtkWidget *align_end_button;
   GtkWidget *hbox;
   GtkWidget *label;
   GtkWidget *fit_button;
-  GtkWidget *hseparator;
   GtkWidget *transition_combo;
-  GObject *spinbutton_adj;
   GtkWidget *dialog_action_area;
   GtkWidget *cancelbutton;
   GtkWidget *okbutton;
 
-  int i,idx=0;
-  lives_rfx_t *rfx;
+  GSList *radiobutton_align_group = NULL;
+  GSList *radiobutton_insdrop_group = NULL;
+
+  GList *retvals;
+
+  GtkAccelGroup *accel_group;
 
-  gint cb_frames=clipboard->frames;
   gchar *txt;
 
-  gint defstart=0;
+  int idx=0;
+
+  int cb_frames=clipboard->frames;
+  int defstart=0;
+
+  register int i;
 
   merge_opts=(_merge_opts*)(g_malloc(sizeof(_merge_opts)));
   merge_opts->list_to_rfx_index=(int *)g_malloc (sizint*(mainw->num_rendered_effects_builtin+
@@ -51,6 +57,8 @@ void create_merge_dialog (void) {
 							 mainw->num_rendered_effects_test));
   merge_opts->trans_list=NULL;
 
+  merge_opts->spinbutton_loops=NULL;
+
   for (i=0;i<mainw->num_rendered_effects_builtin+mainw->num_rendered_effects_custom+mainw->num_rendered_effects_test;i++) {
     if ((rfx=&mainw->rendered_fx[i])->num_in_channels==2) {
       if (i==mainw->last_transition_idx) defstart=idx;
@@ -74,34 +82,22 @@ void create_merge_dialog (void) {
     return;
   }
 
+  merge_opts->merge_dialog = lives_standard_dialog_new (_("LiVES: - Merge"),FALSE);
 
+  accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+  gtk_window_add_accel_group (GTK_WINDOW (merge_opts->merge_dialog), accel_group);
 
-  merge_opts->merge_dialog = gtk_dialog_new ();
-  gtk_container_set_border_width (GTK_CONTAINER (merge_opts->merge_dialog), 10);
-  gtk_window_set_title (GTK_WINDOW (merge_opts->merge_dialog), _("LiVES: - Merge"));
-  gtk_window_set_position (GTK_WINDOW (merge_opts->merge_dialog), GTK_WIN_POS_CENTER_ALWAYS);
-  gtk_window_set_modal (GTK_WINDOW (merge_opts->merge_dialog), TRUE);
-  gtk_window_set_default_size (GTK_WINDOW(merge_opts->merge_dialog), 720, -1);
-  gtk_dialog_set_has_separator(GTK_DIALOG(merge_opts->merge_dialog),FALSE);
-
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_bg (merge_opts->merge_dialog, GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  if (!prefs->show_gui) {
+  if (prefs->show_gui) {
     gtk_window_set_transient_for(GTK_WINDOW(merge_opts->merge_dialog),GTK_WINDOW(mainw->LiVES));
   }
 
   dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(merge_opts->merge_dialog));
-  gtk_widget_show (dialog_vbox);
 
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox);
+  vbox = lives_vbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (dialog_vbox), vbox, TRUE, TRUE, 0);
 
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 19);
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height*2);
 
   txt=g_strdup_printf(_ ("Merge Clipboard [ %d Frames ]       With Selection [ %d Frames ]"),clipboard->frames,cfile->end-cfile->start+1);
   if (prefs->ins_resample&&clipboard->fps!=cfile->fps) {
@@ -112,232 +108,163 @@ void create_merge_dialog (void) {
     }
   }
 
-  label = gtk_label_new (txt);
+  label = lives_standard_label_new (txt);
   g_free(txt);
-  gtk_widget_show (label);
+
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
 
-  label = gtk_label_new ("");
-  gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+  add_fill_to_box(LIVES_BOX(hbox));
 
-  align_start_button = gtk_radio_button_new (NULL);
+  align_start_button = lives_standard_radio_button_new (_("Align _Starts"),TRUE,radiobutton_align_group,LIVES_BOX(hbox),NULL);
+  radiobutton_align_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (align_start_button));
 
-  gtk_widget_show (align_start_button);
-  gtk_box_pack_start (GTK_BOX (hbox),align_start_button, TRUE, FALSE, 0);
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (align_start_button), radiobutton_align_group);
-  radiobutton_align_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (align_start_button));
+  add_fill_to_box(LIVES_BOX(hbox));
 
-  label = gtk_label_new_with_mnemonic ( _("Align _Starts"));
-  gtk_widget_show (label);
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label),align_start_button);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
+  align_end_button = lives_standard_radio_button_new (_("Align _Ends"),TRUE,radiobutton_align_group,LIVES_BOX(hbox),NULL);
 
-  label = gtk_label_new ("");
-  gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+  lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(align_end_button),!mainw->last_transition_align_start);
 
-  align_end_button = gtk_radio_button_new (radiobutton_align_group);
-  gtk_widget_show (align_end_button);
-  gtk_box_pack_start (GTK_BOX (hbox), align_end_button, TRUE, FALSE, 0);
-  radiobutton_align_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (align_end_button));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg (align_end_button, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(align_end_button),!mainw->last_transition_align_start);
-  
 
-  label = gtk_label_new_with_mnemonic ( _("Align _Ends"));
-  gtk_widget_show (label);
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label),align_end_button);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
 
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 22);
-
-  spinbutton_adj = (GObject *)gtk_adjustment_new (1, 1, (gint)((cfile->end-cfile->start+1)/cb_frames), 1, 10, 0);
-  merge_opts->spinbutton_loops = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adj), 1, 0);
-  merge_opts->ins_frame_button = gtk_radio_button_new (NULL);
-  merge_opts->drop_frame_button = gtk_radio_button_new (NULL);
-  fit_button = gtk_check_button_new ();
-
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops),mainw->last_transition_loops);
-
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fit_button),mainw->last_transition_loop_to_fit);
-
-  gtk_widget_set_sensitive(merge_opts->spinbutton_loops,!mainw->last_transition_loop_to_fit);
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, widget_opts.packing_height*2);
 
   if ((cfile->end-cfile->start+1)<cb_frames) {
     // hide loop controls if selection is smaller than clipboard
-    label = gtk_label_new (_("What to do with extra clipboard frames -"));
-    gtk_widget_show (label);
+    label = lives_standard_label_new (_("What to do with extra clipboard frames -"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-    }
 
-    gtk_widget_show (merge_opts->ins_frame_button);
-    gtk_box_pack_start (GTK_BOX (hbox), merge_opts->ins_frame_button, TRUE, FALSE, 0);
-    label = gtk_label_new_with_mnemonic (_("_Insert Frames"));
-    gtk_widget_show (label);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),merge_opts->ins_frame_button);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-    }
+    merge_opts->ins_frame_button=lives_standard_radio_button_new(_("_Insert Frames"),TRUE,radiobutton_insdrop_group,LIVES_BOX(hbox),NULL);
+    radiobutton_insdrop_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (merge_opts->ins_frame_button));
 
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (merge_opts->ins_frame_button), radiobutton_insdrop_group);
-    radiobutton_insdrop_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (merge_opts->ins_frame_button));
+    merge_opts->ins_frame_function=g_signal_connect (GTK_OBJECT (merge_opts->ins_frame_button),
+						     "toggled",G_CALLBACK (on_ins_frames_toggled),NULL);
 
-    gtk_widget_show (merge_opts->drop_frame_button);
-    gtk_box_pack_start (GTK_BOX (hbox), merge_opts->drop_frame_button, TRUE, FALSE, 0);
+    merge_opts->drop_frame_button=lives_standard_radio_button_new(_("_Drop Frames"),TRUE,radiobutton_insdrop_group,LIVES_BOX(hbox),NULL);
 
-    label = gtk_label_new_with_mnemonic (_("_Drop Frames"));
-    gtk_widget_show (label);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),merge_opts->drop_frame_button);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-    }
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (merge_opts->drop_frame_button), radiobutton_insdrop_group);
-    radiobutton_insdrop_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (merge_opts->drop_frame_button));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(merge_opts->drop_frame_button),!mainw->last_transition_ins_frames);
+    lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(merge_opts->drop_frame_button),!mainw->last_transition_ins_frames);
   }
   else if ((cfile->end-cfile->start+1)>cb_frames) {
+    merge_opts->spinbutton_loops = lives_standard_spin_button_new 
+      (_("Number of Times to Loop Clipboard"),FALSE,1.,1.,
+       (int)((cfile->end-cfile->start+1)/cb_frames), 1., 10., 0, LIVES_BOX(hbox), NULL);
     
-    label = gtk_label_new_with_mnemonic (_("Number of Times to Loop Clipboard"));
-    gtk_widget_show (label);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),merge_opts->spinbutton_loops);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-    }
-    gtk_widget_show (merge_opts->spinbutton_loops);
-    gtk_box_pack_start (GTK_BOX (hbox), merge_opts->spinbutton_loops, TRUE, FALSE, 0);
 
-    gtk_widget_show (fit_button);
-    gtk_box_pack_start (GTK_BOX (hbox), fit_button, FALSE, FALSE, 0);
-    label = gtk_label_new_with_mnemonic (_ ("_Loop Clipboard to Fit Selection"));
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label),fit_button);
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &palette->normal_fore);
-    }
-  }
-  else {
-    gtk_widget_hide(hbox);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops),mainw->last_transition_loops);
+    gtk_widget_set_sensitive(merge_opts->spinbutton_loops,!mainw->last_transition_loop_to_fit);
+
+    g_signal_connect_after (GTK_OBJECT (merge_opts->spinbutton_loops), "value_changed",
+			    G_CALLBACK (after_spinbutton_loops_changed),
+			    NULL);
+
+    fit_button = lives_standard_check_button_new (_("_Loop Clipboard to Fit Selection"),TRUE,LIVES_BOX(hbox),NULL);
+    lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(fit_button),mainw->last_transition_loop_to_fit);
+
+    g_signal_connect (GTK_OBJECT (fit_button), "toggled",
+		      G_CALLBACK (on_fit_toggled),
+		      NULL);
   }
 
-  hseparator = gtk_hseparator_new ();
-  gtk_widget_show (hseparator);
-  gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 0);
+  add_hsep_to_box(LIVES_BOX(vbox));
   
-  hbox = gtk_hbox_new (TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 10);
+  hbox = lives_hbox_new (TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
   transition_combo = lives_standard_combo_new (_("_Transition Method:"),TRUE,merge_opts->trans_list,LIVES_BOX(hbox),NULL);
-  gtk_widget_show_all(hbox);
 
   gtk_combo_box_set_active(GTK_COMBO_BOX(transition_combo),defstart);
 
   mainw->last_transition_idx=merge_opts->list_to_rfx_index[defstart];
 
-  hseparator = gtk_hseparator_new ();
-  gtk_widget_show (hseparator);
-  gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 0);
+  add_hsep_to_box(LIVES_BOX(vbox));
 
-  do_onchange_init(rfx);
 
   // now the dynamic part...
-  merge_opts->param_vbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER(merge_opts->param_vbox), 10);
+  merge_opts->param_vbox = lives_vbox_new (FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER(merge_opts->param_vbox), widget_opts.border_width>>1);
 
   gtk_box_pack_start (GTK_BOX (vbox), merge_opts->param_vbox, TRUE, TRUE, 0);
 
   rfx=&mainw->rendered_fx[mainw->last_transition_idx];
+  mainw->overflow_height=900;
   make_param_box(GTK_VBOX (merge_opts->param_vbox), rfx);
+  mainw->overflow_height=0;
   gtk_widget_show_all (merge_opts->param_vbox);
+
+  retvals=do_onchange_init(rfx);
+
+  if (retvals!=NULL) {
+    // now apply visually anything we got from onchange_init
+    //param_demarshall (rfx,retvals,TRUE,TRUE);
+    g_list_free_strings (retvals);
+    g_list_free (retvals);
+  }
+
   // done !
 
 
   dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (merge_opts->merge_dialog));
-  gtk_widget_show (dialog_action_area);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
 
   cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
-  gtk_widget_show (cancelbutton);
   gtk_dialog_add_action_widget (GTK_DIALOG (merge_opts->merge_dialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  lives_widget_set_can_focus_and_default (cancelbutton);
+  lives_widget_set_can_focus (cancelbutton,TRUE);
 
   okbutton = gtk_button_new_from_stock ("gtk-ok");
-  gtk_widget_show (okbutton);
   gtk_dialog_add_action_widget (GTK_DIALOG (merge_opts->merge_dialog), okbutton, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
-
- 
-
-
+  gtk_widget_grab_default (okbutton);
 
   g_signal_connect (GTK_OBJECT (cancelbutton), "clicked",
                       G_CALLBACK (on_merge_cancel_clicked),
                       rfx);
 
+
+  gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+                              LIVES_KEY_Escape,  (GdkModifierType)0, (GtkAccelFlags)0);
+
+
   g_signal_connect (GTK_OBJECT (okbutton), "clicked",
                       G_CALLBACK (on_merge_ok_clicked),
                       rfx);
-
-   g_signal_connect (GTK_OBJECT(transition_combo),"changed",G_CALLBACK (on_trans_method_changed),NULL);
-
+  
+  g_signal_connect (GTK_OBJECT(transition_combo),"changed",G_CALLBACK (on_trans_method_changed),NULL);
+  
 
   g_signal_connect (GTK_OBJECT (align_start_button), "toggled",
 		    G_CALLBACK (on_align_start_end_toggled),
 		    rfx);
 
 
-  if ((cfile->end-cfile->start+1)>cb_frames) {
-    g_signal_connect (GTK_OBJECT (fit_button), "toggled",
-		      G_CALLBACK (on_fit_toggled),
-		      NULL);
-  }
-  else if ((cfile->end-cfile->start+1)<cb_frames) {
-    merge_opts->ins_frame_function=g_signal_connect (GTK_OBJECT (merge_opts->ins_frame_button), "toggled",G_CALLBACK (on_ins_frames_toggled),NULL);
+  if (prefs->show_gui) {
+    gtk_widget_show_all(merge_opts->merge_dialog);
   }
+}
 
-  g_signal_connect_after (GTK_OBJECT (merge_opts->spinbutton_loops), "value_changed",
-			  G_CALLBACK (after_spinbutton_loops_changed),
-			  NULL);
+static void bang (GtkWidget *widget, gpointer null) {
+  gtk_widget_destroy (widget);
 }
 
 
-
-
 void on_trans_method_changed (GtkComboBox *combo, gpointer user_data) {
-  int idx;
   lives_rfx_t *rfx;
+
+  GList *retvals;
+
   char *txt=lives_combo_get_active_text (combo);
 
+  int idx;
+
   if (!strlen (txt)) {
     g_free(txt);
     return;
   }
 
+  rfx=&mainw->rendered_fx[mainw->last_transition_idx];
+
+  gtk_container_foreach (GTK_CONTAINER(merge_opts->param_vbox),bang,NULL);
+  on_paramwindow_cancel_clicked (NULL,rfx);
+
   idx=lives_list_index(merge_opts->trans_list,txt);
 
   g_free(txt);
@@ -345,24 +272,24 @@ void on_trans_method_changed (GtkComboBox *combo, gpointer user_data) {
   mainw->last_transition_idx=merge_opts->list_to_rfx_index[idx];
   rfx=&mainw->rendered_fx[mainw->last_transition_idx];
 
-  gtk_container_foreach (GTK_CONTAINER(merge_opts->param_vbox),bang,NULL);
-  on_paramwindow_cancel_clicked (NULL,rfx);
-
-  do_onchange_init(rfx);
-
   make_param_box(GTK_VBOX (merge_opts->param_vbox), rfx);
   gtk_widget_show_all (merge_opts->param_vbox);
+
+  retvals=do_onchange_init(rfx);
+
+  if (retvals!=NULL) {
+    // now apply visually anything we got from onchange_init
+    param_demarshall (rfx,retvals,TRUE,TRUE);
+    g_list_free_strings (retvals);
+    g_list_free (retvals);
+  }
+
   merge_opts->align_start=!merge_opts->align_start;
   on_align_start_end_toggled (NULL,NULL);
 }
 
 
 
-void bang (GtkWidget *widget, gpointer null) {
-  gtk_widget_destroy (widget);
-}
-
-
 
 void
 on_merge_activate                     (GtkMenuItem     *menuitem,
@@ -374,7 +301,6 @@ on_merge_activate                     (GtkMenuItem     *menuitem,
   merge_opts->ins_frames=mainw->last_transition_ins_frames;
   merge_opts->align_start=!mainw->last_transition_align_start;
 
-  gtk_widget_show (merge_opts->merge_dialog);
   on_align_start_end_toggled (NULL,NULL);
 }
 
@@ -386,9 +312,10 @@ on_merge_cancel_clicked                   (GtkButton       *button,
 {
   lives_rfx_t *rfx=(lives_rfx_t *)user_data;
   on_paramwindow_cancel_clicked (NULL,rfx);
-  mainw->last_transition_loops=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops));
+  if (merge_opts->spinbutton_loops!=NULL) 
+    mainw->last_transition_loops=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops));
   gtk_widget_destroy(merge_opts->merge_dialog);
-  while (g_main_context_iteration (NULL,FALSE));
+  lives_widget_context_update();
   mainw->last_transition_loop_to_fit=merge_opts->loop_to_fit;
   mainw->last_transition_ins_frames=merge_opts->ins_frames;
   mainw->last_transition_align_start=merge_opts->align_start;
@@ -410,7 +337,7 @@ on_merge_ok_clicked                   (GtkButton       *button,
   gint start,end;
 
   gint cb_start=1;
-  gboolean cb_video_change=FALSE;
+  boolean cb_video_change=FALSE;
   gint current_file=mainw->current_file;
   gint old_frames=clipboard->frames;
 
@@ -422,7 +349,9 @@ on_merge_ok_clicked                   (GtkButton       *button,
 
   lives_rfx_t *rfx;
 
-  mainw->last_transition_loops=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops));
+  if (merge_opts->spinbutton_loops!=NULL) 
+    mainw->last_transition_loops=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (merge_opts->spinbutton_loops));
+
   mainw->last_transition_loop_to_fit=merge_opts->loop_to_fit;
   mainw->last_transition_ins_frames=merge_opts->ins_frames;
   mainw->last_transition_align_start=merge_opts->align_start;
@@ -433,7 +362,7 @@ on_merge_ok_clicked                   (GtkButton       *button,
     if (!do_clipboard_fps_warning()) {
       on_paramwindow_cancel_clicked (NULL,rfx);
       gtk_widget_destroy(merge_opts->merge_dialog);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
       g_list_free (merge_opts->trans_list);
       g_free (merge_opts->list_to_rfx_index);
       g_free(merge_opts);
@@ -441,11 +370,14 @@ on_merge_ok_clicked                   (GtkButton       *button,
     }
   }
 
-  times_to_loop=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(merge_opts->spinbutton_loops));
+  if (merge_opts->spinbutton_loops!=NULL) 
+    times_to_loop=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(merge_opts->spinbutton_loops));
+  else 
+    times_to_loop=1;
 
   on_paramwindow_cancel_clicked (NULL,rfx);
   gtk_widget_destroy(merge_opts->merge_dialog);
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
   g_list_free (merge_opts->trans_list);
   g_free (merge_opts->list_to_rfx_index);
   g_free(merge_opts);
@@ -481,7 +413,7 @@ on_merge_ok_clicked                   (GtkButton       *button,
   // insert pre-frames
   if (!mainw->last_transition_align_start&&excess_frames>0&&mainw->last_transition_ins_frames) {
     mainw->insert_after=FALSE;
-    msg=g_strdup_printf(_ ("inserting %d extra frame(s) before merge\n"),excess_frames);
+    msg=g_strdup_printf(P_ ("inserting %d extra frame before merge\n","inserting %d extra frames before merge\n",excess_frames),excess_frames);
     d_print(msg);
     g_free(msg);
   
@@ -600,7 +532,7 @@ on_merge_ok_clicked                   (GtkButton       *button,
   // insert any post frames
   if (mainw->last_transition_align_start&&excess_frames>0&&mainw->last_transition_ins_frames) {
     mainw->insert_after=TRUE;
-    msg=g_strdup_printf(_ ("now inserting %d extra frame(s)\n"),excess_frames);
+    msg=g_strdup_printf(P_ ("now inserting %d extra frame\n","now inserting %d extra frames\n",excess_frames),excess_frames);
     d_print(msg);
     g_free(msg);
     
