@@ -1,6 +1,6 @@
 // omc-learn.c
 // LiVES (lives-exe)
-// (c) G. Finch 2008 - 2012
+// (c) G. Finch 2008 - 2013
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -64,7 +64,7 @@ static OSCbuf obuf;
 static gchar byarr[OSC_BUF_SIZE];
 static lives_omc_macro_t omc_macros[N_OMC_MACROS];
 static GSList *omc_node_list;
-static gboolean omc_macros_inited=FALSE;
+static boolean omc_macros_inited=FALSE;
 
 //////////////////////////////////////////////////////////////
 
@@ -93,7 +93,7 @@ static void omc_match_node_free(lives_omc_match_node_t *mnode) {
 
 
 
-static void remove_all_nodes(gboolean every, omclearn_w *omclw) {
+static void remove_all_nodes(boolean every, omclearn_w *omclw) {
   lives_omc_match_node_t *mnode;
   GSList *slist_last=NULL,*slist_next;
   GSList *slist=omc_node_list;
@@ -174,7 +174,7 @@ const gchar * get_js_filename(void) {
 #endif
 
 
-gboolean js_open(void) {
+boolean js_open(void) {
   gchar *msg;
 
   if (!(prefs->omc_dev_opts&OMC_DEV_JS)) return TRUE;
@@ -275,7 +275,7 @@ gchar *midi_fname;
 #endif
 
 
-gboolean midi_open(void) {
+boolean midi_open(void) {
 
 #ifndef IS_MINGW  
   gchar *msg;
@@ -410,7 +410,7 @@ gchar *midi_mangle(void) {
   ssize_t bytes,tot=0,allowed=prefs->midi_rpt;
   unsigned char midbuf[4],xbuf[4];
   gint target=1,mtype=0,idx;
-  gboolean got_target=FALSE;
+  boolean got_target=FALSE;
   gchar *str;
 
 #ifdef ALSA_MIDI
@@ -418,7 +418,7 @@ gchar *midi_mangle(void) {
   struct pollfd *pfd=NULL;
   snd_seq_event_t *ev;
   int typeNumber;
-  gboolean hasmore=FALSE;
+  boolean hasmore=FALSE;
 
   if (mainw->seq_handle!=NULL) {
 
@@ -708,7 +708,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, om
   mnode->treev2 = gtk_tree_view_new_with_model (GTK_TREE_MODEL (mnode->gtkstore2));
 
   if (palette->style&STYLE_1) {
-    gtk_widget_modify_base(mnode->treev2, GTK_STATE_NORMAL, &palette->menu_and_bars);
+    lives_widget_set_base_color(mnode->treev2, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
   }
 
   renderer = gtk_cell_renderer_text_new ();
@@ -1031,7 +1031,8 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
        else valstr=g_strdup("-");
      }
 
-     gtk_tree_store_set (mnode->gtkstore, &iter2, TITLE_COLUMN, vname, VALUE_COLUMN, valstr, FILTER_COLUMN, mnode->matchp[i], RANGE_COLUMN, strval, OFFS1_COLUMN, strval2, SCALE_COLUMN, strval3, OFFS2_COLUMN, strval4, -1);
+     gtk_tree_store_set (mnode->gtkstore, &iter2, TITLE_COLUMN, vname, VALUE_COLUMN, valstr, FILTER_COLUMN, mnode->matchp[i], 
+			 RANGE_COLUMN, strval, OFFS1_COLUMN, strval2, SCALE_COLUMN, strval3, OFFS2_COLUMN, strval4, -1);
 
      g_free (strval);
      g_free (strval2);
@@ -1074,13 +1075,9 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
      break;
    }
 
-   label = gtk_label_new (labelt);
+   label = lives_standard_label_new (labelt);
    gtk_widget_show (label);
    
-   if (palette->style&STYLE_1) {
-     gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-   }
-
    if (labelt!=NULL) g_free(labelt);
      
    omclw->tbl_currow++;
@@ -1090,7 +1087,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
 
    // properties
   if (palette->style&STYLE_1) {
-    gtk_widget_modify_base(mnode->treev1, GTK_STATE_NORMAL, &palette->menu_and_bars);
+    lives_widget_set_base_color(mnode->treev1, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
   }
 
    renderer = gtk_cell_renderer_text_new ();
@@ -1310,48 +1307,27 @@ static omclearn_w *create_omclearn_dialog(void) {
     scr_height=mainw->mgeom[prefs->gui_monitor-1].height;
   }
   
-  winsize_h=scr_width-100;
-  winsize_v=scr_height-100;
+  winsize_h=scr_width-SCR_WIDTH_SAFETY;
+  winsize_v=scr_height-SCR_HEIGHT_SAFETY*2;
   
-  omclw->dialog = gtk_dialog_new ();
+  omclw->dialog = lives_standard_dialog_new (_("LiVES: OMC learner"),FALSE);
   
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_bg(omclw->dialog, GTK_STATE_NORMAL, &palette->menu_and_bars);
-  }
-
-  gtk_window_set_title (GTK_WINDOW (omclw->dialog), _("LiVES: OMC learner"));
-  gtk_window_add_accel_group (GTK_WINDOW (omclw->dialog), mainw->accel_group);
   omclw->top_vbox = lives_dialog_get_content_area(GTK_DIALOG(omclw->dialog));
 
   omclw->table = gtk_table_new (omclw->tbl_rows, 4, FALSE);
-  gtk_widget_show (omclw->table);
 
-  gtk_table_set_col_spacings(GTK_TABLE(omclw->table),20);
+  gtk_table_set_col_spacings(GTK_TABLE(omclw->table),widget_opts.packing_width*2);
+
+  scrolledwindow = lives_standard_scrolled_window_new (winsize_h, winsize_v, omclw->table);
 
-  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_show (scrolledwindow);
   gtk_box_pack_start (GTK_BOX (omclw->top_vbox), scrolledwindow, TRUE, TRUE, 0);
-  
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), omclw->table);
-  gtk_widget_set_size_request (scrolledwindow, winsize_h, winsize_v);
-  
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_bg(gtk_bin_get_child (GTK_BIN (scrolledwindow)), GTK_STATE_NORMAL, &palette->normal_back);
-  }
-  
-  gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (scrolledwindow))),GTK_SHADOW_IN);
-  
-  hbuttonbox = gtk_hbutton_box_new ();
-  gtk_widget_show (hbuttonbox);
-  
-  gtk_box_pack_start (GTK_BOX (omclw->top_vbox), hbuttonbox, TRUE, TRUE, 0);
-  
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
+
+
+
+  hbuttonbox = lives_dialog_get_action_area(LIVES_DIALOG(omclw->dialog));
   
   omclw->clear_button = gtk_button_new_with_mnemonic (_("Clear _unmatched"));
-  gtk_widget_show (omclw->clear_button);
+
   gtk_container_add (GTK_CONTAINER (hbuttonbox), omclw->clear_button);
   
 
@@ -1362,7 +1338,7 @@ static omclearn_w *create_omclearn_dialog(void) {
   gtk_widget_set_sensitive(omclw->clear_button,FALSE);
 
   omclw->del_all_button = gtk_button_new_with_mnemonic (_("_Delete all"));
-  gtk_widget_show (omclw->del_all_button);
+
   gtk_container_add (GTK_CONTAINER (hbuttonbox), omclw->del_all_button);
   
 
@@ -1374,12 +1350,22 @@ static omclearn_w *create_omclearn_dialog(void) {
 
 
   ok_button = gtk_button_new_with_mnemonic (_("Close _window"));
-  gtk_widget_show (ok_button);
+
   gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
   
   lives_widget_set_can_focus_and_default (ok_button);
 
   gtk_widget_grab_default (ok_button);
+
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
+#else
+  gtk_widget_set_size_request(ok_button,DEF_BUTTON_WIDTH*4,-1);
+  gtk_widget_set_size_request(omclw->clear_button,DEF_BUTTON_WIDTH*4,-1);
+  gtk_widget_set_size_request(omclw->del_all_button,DEF_BUTTON_WIDTH*4,-1);
+#endif
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
+  
   
   g_signal_connect (GTK_OBJECT (ok_button), "clicked",
 		    G_CALLBACK (close_learner_dialog),
@@ -1397,6 +1383,9 @@ static omclearn_w *create_omclearn_dialog(void) {
   if (prefs->open_maximised) {
     gtk_window_maximize (GTK_WINDOW(omclw->dialog));
   }
+
+  if (prefs->show_gui)
+    gtk_widget_show_all(omclw->dialog);
   
   return omclw;
 }
@@ -1681,7 +1670,7 @@ static int get_nfixed(gint type, const gchar *string) {
 
 
 
-static gboolean match_filtered_params(lives_omc_match_node_t *mnode, const gchar *sig, int nfixed) {
+static boolean match_filtered_params(lives_omc_match_node_t *mnode, const gchar *sig, int nfixed) {
   int i;
   gchar **array=g_strsplit(sig," ",-1);
 
@@ -1821,7 +1810,7 @@ static lives_omc_match_node_t *lives_omc_match_node_new(gint str_type, gint inde
     mnode->offs1=(gint *)g_malloc(mnode->nvars*sizint);
     mnode->min=(gint *)g_malloc(mnode->nvars*sizint);
     mnode->max=(gint *)g_malloc(mnode->nvars*sizint);
-    mnode->matchp=(gboolean *)g_malloc(mnode->nvars*sizeof(gboolean));
+    mnode->matchp=(boolean *)g_malloc(mnode->nvars*sizeof(boolean));
     mnode->matchi=(gint *)g_malloc(mnode->nvars*sizint);
   }
 
@@ -2037,13 +2026,13 @@ lives_omc_match_node_t *omc_learn(const gchar *string, gint str_type, gint idx,
 
 // in playback mode, we match the string with our database, and then convert/append the variables
 
-gboolean omc_process_string(gint supertype, const gchar *string, gboolean learn, omclearn_w *omclw) {
+boolean omc_process_string(gint supertype, const gchar *string, boolean learn, omclearn_w *omclw) {
   // only need to set omclw if learn is TRUE
   
   // returns TRUE if we learn new, or if we carry out an action
   // retruns FALSE otherwise
 
-  gboolean ret=FALSE;
+  boolean ret=FALSE;
   int type=0,idx=-1;
   lives_omc_match_node_t *mnode;
 
@@ -2162,7 +2151,7 @@ void on_midi_learn_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
     g_usleep(prefs->sleep_time);
 
-    while (g_main_context_iteration(NULL,FALSE));
+    lives_widget_context_update();
   }
 
   remove_all_nodes(FALSE,omclw);
@@ -2428,7 +2417,7 @@ OSCbuf *omc_learner_decode(gint type, gint idx, const gchar *string) {
 
 
 void on_midi_save_activate (GtkMenuItem *menuitem, gpointer user_data) {
-  gchar *save_file=choose_file(NULL,NULL,NULL,GTK_FILE_CHOOSER_ACTION_SAVE,NULL,NULL);
+  gchar *save_file=choose_file(NULL,NULL,NULL,LIVES_FILE_CHOOSER_ACTION_SAVE,NULL,NULL);
   int fd;
   GSList *slist=omc_node_list;
   size_t srchlen;
@@ -2556,7 +2545,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
   gchar *tmp;
 #endif 
 
-  if (user_data==NULL) load_file=choose_file(NULL,NULL,NULL,GTK_FILE_CHOOSER_ACTION_OPEN,NULL,NULL);
+  if (user_data==NULL) load_file=choose_file(NULL,NULL,NULL,LIVES_FILE_CHOOSER_ACTION_OPEN,NULL,NULL);
   else load_file=g_strdup((gchar *)user_data);
 
   if (load_file==NULL) return;
