@@ -25,9 +25,6 @@
 #include "effects.h"
 #include "paramwindow.h"
 
-#define RTE_INFO_WIDTH 350
-#define RTE_INFO_HEIGHT 200
-
 static GtkWidget **key_checks;
 static GtkWidget **key_grabs;
 static GtkWidget **mode_radios;
@@ -85,10 +82,6 @@ void type_label_set_text (int key, int mode) {
 }
 
 
-void on_rtei_ok_clicked (GtkButton *button, gpointer user_data) {
-  gtk_widget_destroy(gtk_widget_get_toplevel(GTK_WIDGET(button)));
-}
-
 
 boolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
   int modes=rte_getmodespk();
@@ -108,7 +101,7 @@ boolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
   cconx_delete_all();
 
   for (i=0;i<prefs->rte_keys_virtual;i++) {
-    if (rte_window!=NULL) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(key_checks[i]),FALSE);
+    if (rte_window!=NULL) lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[i]),FALSE);
     for (j=modes-1;j>=0;j--) {
       weed_delete_effectkey (i+1,j);
       if (rte_window!=NULL) {
@@ -152,7 +145,7 @@ static boolean save_keymap2_file(gchar *kfname) {
 	  if (rte_keymode_valid(i,j,TRUE)) {
 	    lives_write_le(kfd,&i,4,TRUE);
 	    if (mainw->write_failed) break;
-	    hashname=g_strdup_printf("Weed%s",(tmp=make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE)));
+	    hashname=g_strdup_printf("Weed%s",(tmp=make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE,FALSE)));
 	    g_free(tmp);
 	    slen=strlen(hashname);
 	    lives_write_le(kfd,&slen,4,TRUE);
@@ -224,7 +217,7 @@ static boolean save_keymap3_file(gchar *kfname) {
 	  lives_write_le(kfd,&cconx->omode,4,TRUE);
 	  if (mainw->write_failed) goto write_failed1;
 
-	  hashname=make_weed_hashname(rte_keymode_get_filter_idx(cconx->okey+1,cconx->omode),TRUE);
+	  hashname=make_weed_hashname(rte_keymode_get_filter_idx(cconx->okey+1,cconx->omode),TRUE,FALSE);
 	  slen=strlen(hashname);
 	  lives_write_le(kfd,&slen,4,TRUE);
 	  lives_write(kfd,hashname,slen,TRUE);
@@ -251,7 +244,7 @@ static boolean save_keymap3_file(gchar *kfname) {
 	      lives_write_le(kfd,&cconx->imode[j],4,TRUE);
 	      if (mainw->write_failed) goto write_failed1;
 	      
-	      hashname=make_weed_hashname(rte_keymode_get_filter_idx(cconx->ikey[j]+1,cconx->imode[j]),TRUE);
+	      hashname=make_weed_hashname(rte_keymode_get_filter_idx(cconx->ikey[j]+1,cconx->imode[j]),TRUE,FALSE);
 	      slen=strlen(hashname);
 	      lives_write_le(kfd,&slen,4,TRUE);
 	      lives_write(kfd,hashname,slen,TRUE);
@@ -299,7 +292,7 @@ static boolean save_keymap3_file(gchar *kfname) {
 	  lives_write_le(kfd,&pconx->omode,4,TRUE);
 	  if (mainw->write_failed) goto write_failed1;
 
-	  hashname=make_weed_hashname(rte_keymode_get_filter_idx(pconx->okey+1,pconx->omode),TRUE);
+	  hashname=make_weed_hashname(rte_keymode_get_filter_idx(pconx->okey+1,pconx->omode),TRUE,FALSE);
 	  slen=strlen(hashname);
 	  lives_write_le(kfd,&slen,4,TRUE);
 	  lives_write(kfd,hashname,slen,TRUE);
@@ -326,7 +319,7 @@ static boolean save_keymap3_file(gchar *kfname) {
 	      lives_write_le(kfd,&pconx->imode[j],4,TRUE);
 	      if (mainw->write_failed) goto write_failed1;
 
-	      hashname=make_weed_hashname(rte_keymode_get_filter_idx(pconx->ikey[j]+1,pconx->imode[j]),TRUE);
+	      hashname=make_weed_hashname(rte_keymode_get_filter_idx(pconx->ikey[j]+1,pconx->imode[j]),TRUE,FALSE);
 	      slen=strlen(hashname);
 	      lives_write_le(kfd,&slen,4,TRUE);
 	      lives_write(kfd,hashname,slen,TRUE);
@@ -436,7 +429,7 @@ static boolean on_save_keymap_clicked (GtkButton *button, gpointer user_data) {
 	for (i=1;i<=prefs->rte_keys_virtual;i++) {
 	  for (j=0;j<modes;j++) {
 	    if (rte_keymode_valid(i,j,TRUE)) {
-	      lives_fputs(g_strdup_printf("%d|Weed%s\n",i,(tmp=make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE))),kfile);
+	      lives_fputs(g_strdup_printf("%d|Weed%s\n",i,(tmp=make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE,FALSE))),kfile);
 	      g_free(tmp);
 	    }
 	  }
@@ -508,7 +501,7 @@ void on_save_rte_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
   d_print(msg);
   g_free(msg);
 
-  numfx=rte_get_numfilters();
+  numfx=rte_get_numfilters(FALSE);
 
   do {
     retval=0;
@@ -838,9 +831,14 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	  int fidx=rte_keymode_get_filter_idx(okey+1,omode);
 	  if (fidx==-1) is_valid=FALSE;
 	  else {
-	    gchar *hashname2=make_weed_hashname(fidx,TRUE);
+	    gchar *hashname2=make_weed_hashname(fidx,TRUE,FALSE);
 	    if (strcmp(hashname,hashname2)) is_valid=FALSE;
 	    g_free(hashname2);
+	    if (!is_valid) {
+	      hashname2=make_weed_hashname(fidx,TRUE,TRUE);
+	      if (!strcmp(hashname,hashname2)) is_valid=TRUE;
+	      g_free(hashname2);
+	    }
 	  }
 	}
 
@@ -923,9 +921,14 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	      int fidx=rte_keymode_get_filter_idx(ikey+1,imode);
 	      if (fidx==-1) is_valid2=FALSE;
 	      else {
-		gchar *hashname2=make_weed_hashname(fidx,TRUE);
+		gchar *hashname2=make_weed_hashname(fidx,TRUE,FALSE);
 		if (strcmp(hashname,hashname2)) is_valid2=FALSE;
 		g_free(hashname2);
+		if (!is_valid2) {
+		  hashname2=make_weed_hashname(fidx,TRUE,TRUE);
+		  if (!strcmp(hashname,hashname2)) is_valid2=TRUE;
+		  g_free(hashname2);
+		}
 	      }
 	    }
 
@@ -1001,7 +1004,7 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	  break;
 	}
 
-	hashname=(gchar *)g_try_malloc(hlen);
+	hashname=(gchar *)g_try_malloc(hlen+1);
 
 	if (hashname==NULL) {
 	  eof=TRUE;
@@ -1028,9 +1031,14 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	  int fidx=rte_keymode_get_filter_idx(okey+1,omode);
 	  if (fidx==-1) is_valid=FALSE;
 	  else {
-	    gchar *hashname2=make_weed_hashname(fidx,TRUE);
+	    gchar *hashname2=make_weed_hashname(fidx,TRUE,FALSE);
 	    if (strcmp(hashname,hashname2)) is_valid=FALSE;
 	    g_free(hashname2);
+	    if (!is_valid) {
+	      hashname2=make_weed_hashname(fidx,TRUE,TRUE);
+	      if (!strcmp(hashname,hashname2)) is_valid=TRUE;
+	      g_free(hashname2);
+	    }
 	  }
 	}
 
@@ -1106,9 +1114,14 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	      int fidx=rte_keymode_get_filter_idx(ikey+1,imode);
 	      if (fidx==-1) is_valid2=FALSE;
 	      else {
-		gchar *hashname2=make_weed_hashname(fidx,TRUE);
+		gchar *hashname2=make_weed_hashname(fidx,TRUE,FALSE);
 		if (strcmp(hashname,hashname2)) is_valid2=FALSE;
 		g_free(hashname2);
+		if (!is_valid2) {
+		  hashname2=make_weed_hashname(fidx,TRUE,TRUE);
+		  if (!strcmp(hashname,hashname2)) is_valid2=TRUE;
+		  g_free(hashname2);
+		}
 	      }
 	    }
 
@@ -1210,12 +1223,6 @@ boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
   register int i;
 
-
-  badkeymap=(uint8_t **)g_malloc(prefs->rte_keys_virtual*sizeof(uint8_t *));
-  for (i=0;i<prefs->rte_keys_virtual;i++) {
-    badkeymap[i]=(uint8_t *)lives_calloc(modes,1);
-  }
-
   def_modes=(int *)g_malloc(prefs->rte_keys_virtual*sizint);
   for (i=0;i<prefs->rte_keys_virtual;i++) def_modes[i]=-1;
 
@@ -1547,16 +1554,8 @@ boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
 
 
-void 
-on_rte_info_clicked (GtkButton *button, gpointer user_data) {
-  gint key_mode=GPOINTER_TO_INT(user_data);
-  int modes=rte_getmodespk();
-  int key=(int)(key_mode/modes);
-  int mode=key_mode-key*modes;
-
-  gchar *type;
+void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   weed_plant_t *filter;
-  gchar *plugin_name;
 
   GtkWidget *rte_info_window;
   GtkWidget *vbox;
@@ -1564,18 +1563,26 @@ on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   GtkWidget *label;
   GtkWidget *textview;
 
-  GtkTextBuffer *textbuffer;
-
   GtkWidget *hbuttonbox;
   GtkWidget *ok_button;
 
   gchar *filter_name;
   gchar *filter_author;
+  gchar *filter_extra_authors=NULL;
   gchar *filter_description;
+  gchar *tmp;
+  gchar *type;
+  gchar *plugin_name;
 
   int filter_version;
   int weed_error;
 
+  int key_mode=GPOINTER_TO_INT(user_data);
+  int modes=rte_getmodespk();
+  int key=(int)(key_mode/modes);
+  int mode=key_mode-key*modes;
+
+
   ////////////////////////
 
   if (!rte_keymode_valid(key+1,mode,TRUE)) return;
@@ -1586,6 +1593,7 @@ on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   filter=rte_keymode_get_filter(key+1,mode);
   filter_name=weed_get_string_value(filter,"name",&weed_error);
   filter_author=weed_get_string_value(filter,"author",&weed_error);
+  if (weed_plant_has_leaf(filter,"extra_authors")) filter_extra_authors=weed_get_string_value(filter,"extra_authors",&weed_error);
   if (weed_plant_has_leaf(filter,"description")) filter_description=weed_get_string_value(filter,"description",&weed_error);
   else filter_description=g_strdup(_("No Description"));
 
@@ -1593,93 +1601,64 @@ on_rte_info_clicked (GtkButton *button, gpointer user_data) {
 
   rte_info_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (rte_info_window), g_strdup_printf(_("LiVES: Information for %s"),filter_name));
-  gtk_widget_modify_bg(rte_info_window, GTK_STATE_NORMAL, &palette->normal_back);
+  lives_widget_set_bg_color(rte_info_window, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
 
-  gtk_container_set_border_width (GTK_CONTAINER (rte_info_window), 40);
+  gtk_container_set_border_width (GTK_CONTAINER (rte_info_window), widget_opts.border_width);
   gtk_window_set_transient_for(GTK_WINDOW(rte_info_window),GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(button))));
   gtk_window_set_position (GTK_WINDOW (rte_info_window), GTK_WIN_POS_CENTER_ALWAYS);
   gtk_window_set_default_size (GTK_WINDOW (rte_info_window), RTE_INFO_WIDTH, RTE_INFO_HEIGHT);
 
-  gtk_widget_show(rte_info_window);
-
-  vbox = gtk_vbox_new (FALSE, 20);
-  gtk_widget_show (vbox);
+  vbox = lives_vbox_new (FALSE, widget_opts.packing_height*2);
   gtk_container_add (GTK_CONTAINER (rte_info_window), vbox);
 
-  label = gtk_label_new (g_strdup_printf(_("Effect name: %s"),filter_name));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-    
-  gtk_widget_show (label);
+  label = lives_standard_label_new ((tmp=g_strdup_printf(_("Effect name: %s"),filter_name)));
+  g_free(tmp);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-  label = gtk_label_new (g_strdup_printf(_("Type: %s"),type));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-  
-  gtk_widget_show (label);
+  label = lives_standard_label_new ((tmp=g_strdup_printf(_("Type: %s"),type)));
+  g_free(tmp);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-  label = gtk_label_new (g_strdup_printf(_("Plugin name: %s"),plugin_name));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-  
-  gtk_widget_show (label);
+  label = lives_standard_label_new ((tmp=g_strdup_printf(_("Plugin name: %s"),plugin_name)));
+  g_free(tmp);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-  label = gtk_label_new (g_strdup_printf(_("Author: %s"),filter_author));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-  
-  gtk_widget_show (label);
+  label = lives_standard_label_new ((tmp=g_strdup_printf(_("Author: %s"),filter_author)));
+  g_free(tmp);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-  label = gtk_label_new (g_strdup_printf(_("Version: %d"),filter_version));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
+  if (filter_extra_authors!=NULL) {
+    label = lives_standard_label_new ((tmp=g_strdup_printf(_("and: %s"),filter_extra_authors)));
+    g_free(tmp);
+    gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
   }
 
-  gtk_widget_show (label);
+  label = lives_standard_label_new ((tmp=g_strdup_printf(_("Version: %d"),filter_version)));
+  g_free(tmp);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
 
-  hbox = gtk_hbox_new (FALSE, 10);
-  gtk_widget_show (hbox);
+  hbox = lives_hbox_new (FALSE, widget_opts.packing_width);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
-  label = gtk_label_new (_("Description: "));
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-  }
-  gtk_widget_show (label);
+  label = lives_standard_label_new (_("Description: "));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
   textview = gtk_text_view_new ();
-  gtk_widget_show (textview);
 
   if (palette->style&STYLE_1) {
-    gtk_widget_modify_text(textview, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_base(textview, GTK_STATE_NORMAL, &palette->normal_back);
+    lives_widget_set_text_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
+    lives_widget_set_base_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
   }
-
-
-  textbuffer=gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview));
   
   gtk_text_view_set_editable (GTK_TEXT_VIEW (textview), FALSE);
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview), GTK_WRAP_WORD);
   gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview), FALSE);
   
-  gtk_text_buffer_set_text (textbuffer, filter_description, -1);
+  text_view_set_text (LIVES_TEXT_VIEW(textview), filter_description,-1);
   gtk_box_pack_start (GTK_BOX (hbox), textview, TRUE, TRUE, 0);
   
-  hbuttonbox = gtk_hbutton_box_new ();
-  gtk_widget_show (hbuttonbox);
+  hbuttonbox = lives_hbutton_box_new ();
   gtk_box_pack_start (GTK_BOX (vbox), hbuttonbox, TRUE, TRUE, 0);
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
 
   ok_button = gtk_button_new_from_stock ("gtk-ok");
   gtk_widget_show (ok_button);
@@ -1688,16 +1667,22 @@ on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   lives_widget_set_can_focus_and_default (ok_button);
   gtk_widget_grab_default (ok_button);
 
+  set_button_width(hbuttonbox,ok_button,DEF_BUTTON_WIDTH);
+
   g_signal_connect (GTK_OBJECT (ok_button), "clicked",
-		    G_CALLBACK (on_rtei_ok_clicked),
+		    G_CALLBACK (lives_general_button_clicked),
 		    NULL);
 
   g_free(filter_name);
   g_free(filter_author);
+  if (filter_extra_authors!=NULL) g_free(filter_extra_authors);
   if (weed_plant_has_leaf(filter,"description")) g_free(filter_description);
   else weed_free(filter_description);
   g_free(plugin_name);
   g_free(type);
+
+  gtk_widget_show_all(rte_info_window);
+
 }
 
 
@@ -1842,8 +1827,12 @@ static boolean on_rtew_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 
 
 static void on_rtew_ok_clicked (GtkButton *button, gpointer user_data) {
-  gtk_widget_destroy(gtk_widget_get_toplevel(GTK_WIDGET(button)));
+  lives_set_cursor_style(LIVES_CURSOR_BUSY,NULL);
+  lives_set_cursor_style(LIVES_CURSOR_BUSY,rte_window);
+  lives_widget_context_update();
+  lives_general_button_clicked(button,NULL);
   on_rtew_delete_event (NULL,NULL,NULL);
+  lives_set_cursor_style(LIVES_CURSOR_NORMAL,NULL);
 }
 
 
@@ -1959,7 +1948,7 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
 
 
 
-GtkTreeModel *rte_window_fx_model (void) {
+static LiVESTreeModel *rte_window_fx_model (void) {
   GtkTreeStore *tstore;
 
   GtkTreeIter iter1,iter2;
@@ -2025,7 +2014,7 @@ GtkTreeModel *rte_window_fx_model (void) {
 
   if (pkg!=NULL) g_free(pkg);
 
-  return (GtkTreeModel *)tstore;
+  return (LiVESTreeModel *)tstore;
 }
 
 
@@ -2059,7 +2048,7 @@ GtkWidget * create_rte_window (void) {
 
   GtkAccelGroup *rtew_accel_group;
 
-  GtkTreeModel *model;
+  LiVESTreeModel *model;
 
   weed_plant_t *filter;
 
@@ -2077,7 +2066,8 @@ GtkWidget * create_rte_window (void) {
   register int i,j;
 
   ///////////////////////////////////////////////////////////////////////////
-
+  lives_set_cursor_style(LIVES_CURSOR_BUSY,NULL);
+  lives_widget_context_update();
 
   if (prefs->gui_monitor==0) {
     scr_width=mainw->scr_width;
@@ -2107,17 +2097,17 @@ GtkWidget * create_rte_window (void) {
   mode_ra_fns=(gulong *)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(gulong));
 
   rte_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_widget_modify_bg(rte_window, GTK_STATE_NORMAL, &palette->menu_and_bars);
+  lives_widget_set_bg_color(rte_window, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
   gtk_window_set_title (GTK_WINDOW (rte_window), _("LiVES: Real time effect mapping"));
   gtk_window_add_accel_group (GTK_WINDOW (rte_window), mainw->accel_group);
 
   table = gtk_table_new (prefs->rte_keys_virtual, modes+1, FALSE);
 
-  gtk_table_set_row_spacings (GTK_TABLE (table), 16);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 16*widget_opts.scale);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 4*widget_opts.scale);
 
   // dummy button for "no grab", we dont show this...there is a button instead
-  dummy_radio = gtk_radio_button_new_with_label (grab_group, _("Key grab"));
+  dummy_radio = gtk_radio_button_new (grab_group);
   grab_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (dummy_radio));
 
   name_list=weed_get_all_names(1);
@@ -2126,22 +2116,22 @@ GtkWidget * create_rte_window (void) {
 
   for (i=0;i<prefs->rte_keys_virtual;i++) {
 
-    hbox = gtk_hbox_new (FALSE, 10);
+    hbox = lives_hbox_new (FALSE, 0);
     gtk_table_attach (GTK_TABLE (table), hbox, i, i+1, 0, 1,
 		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
     
     label = lives_standard_label_new ((tmp=g_strdup_printf(_("Ctrl-%d"),i+1)));
     g_free(tmp);
 
-    gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, widget_opts.packing_width);
 
-    hbox2 = gtk_hbox_new (FALSE, 0);
+    hbox2 = lives_hbox_new (FALSE, 0);
 
     key_checks[i] = lives_standard_check_button_new (_("Key active"),FALSE,LIVES_BOX(hbox2),NULL);
     
-    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 10);
+    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
 
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),mainw->rte&(GU641<<i));
 
@@ -2150,8 +2140,8 @@ GtkWidget * create_rte_window (void) {
 
 
 
-    hbox2 = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 10);
+    hbox2 = lives_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
 
     key_grabs[i]=lives_standard_radio_button_new((tmp=g_strdup(_ ("Key grab"))),FALSE,grab_group,LIVES_BOX(hbox2),
 						 (tmp2=g_strdup(_("Grab keyboard for this effect key"))));
@@ -2168,15 +2158,15 @@ GtkWidget * create_rte_window (void) {
 
     for (j=0;j<modes;j++) {
       idx=i*modes+j;
-      hbox = gtk_hbox_new (FALSE, 0);
+      hbox = lives_hbox_new (FALSE, 0);
       gtk_table_attach (GTK_TABLE (table), hbox, i, i+1, j+1, j+2,
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-      gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
+      gtk_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
 
 
-      hbox2 = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 10);
+      hbox2 = lives_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
       
       mode_radios[idx]=lives_standard_radio_button_new(_ ("Mode active"),FALSE,mode_group,LIVES_BOX(hbox2),NULL);
       mode_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (mode_radios[idx]));
@@ -2193,32 +2183,27 @@ GtkWidget * create_rte_window (void) {
       conx_buttons[idx] = gtk_button_new_with_label (_("Set Connections"));
       clear_buttons[idx] = gtk_button_new_with_label (_("Clear"));
 
-      vbox = gtk_vbox_new (FALSE, 15);
-      gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-      gtk_container_set_border_width (GTK_CONTAINER (vbox), 13);
+      vbox = lives_vbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, widget_opts.packing_width);
+      gtk_container_set_border_width (GTK_CONTAINER (vbox), widget_opts.border_width);
 
-      hbox = gtk_hbox_new (FALSE, 12);
-      gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+      hbox = lives_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
       nlabels[idx] = lives_standard_label_new (_("Effect name:"));
 
-      gtk_box_pack_start (GTK_BOX (hbox), nlabels[idx], FALSE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), nlabels[idx], FALSE, FALSE, widget_opts.packing_width);
 
       // create combo entry model
       model=rte_window_fx_model();
 
-#if GTK_CHECK_VERSION(2,24,0)
-      combo = gtk_combo_box_new_with_model_and_entry (model);
-#else
-      combo = gtk_combo_box_entry_new ();
-      gtk_combo_box_set_model(GTK_COMBO_BOX(combo),model);
-#endif
+      combo = lives_combo_new_with_model (model);
 
       lives_combo_set_entry_text_column(LIVES_COMBO(combo),NAME_TYPE_COLUMN);
 
       g_object_set_data (G_OBJECT(combo), "hashname", (gpointer)g_strdup(""));
       g_object_set_data (G_OBJECT(combo), "idx", GINT_TO_POINTER(idx));
-      gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, widget_opts.packing_width);
 
 
       combo_entries[idx] = lives_combo_get_entry(LIVES_COMBO(combo));
@@ -2226,10 +2211,10 @@ GtkWidget * create_rte_window (void) {
       gtk_entry_set_text (GTK_ENTRY (combo_entries[idx]),(tmp=rte_keymode_get_filter_name(i+1,j)));
       g_free(tmp);
  
-      gtk_entry_set_editable (GTK_ENTRY (combo_entries[idx]), FALSE);
+      lives_entry_set_editable (LIVES_ENTRY (combo_entries[idx]), FALSE);
       
-      hbox = gtk_hbox_new (FALSE, 12);
-      gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+      hbox = lives_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
       g_signal_connect(GTK_OBJECT (combo), "changed",
 		       G_CALLBACK (fx_changed),GINT_TO_POINTER(i*rte_getmodespk()+j));
@@ -2248,11 +2233,11 @@ GtkWidget * create_rte_window (void) {
       
       type_label_set_text(i,j);
 
-      gtk_box_pack_start (GTK_BOX (hbox), type_labels[idx], FALSE, FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), info_buttons[idx], FALSE, FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), conx_buttons[idx], FALSE, FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), param_buttons[idx], FALSE, FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), clear_buttons[idx], FALSE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), type_labels[idx], FALSE, FALSE, widget_opts.packing_width);
+      gtk_box_pack_end (GTK_BOX (hbox), info_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      gtk_box_pack_end (GTK_BOX (hbox), conx_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      gtk_box_pack_end (GTK_BOX (hbox), param_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      gtk_box_pack_end (GTK_BOX (hbox), clear_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
 
       filter=rte_keymode_get_filter(i+1,j);
 
@@ -2268,30 +2253,17 @@ GtkWidget * create_rte_window (void) {
   }
 
 
-  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), table);
+  scrolledwindow = lives_standard_scrolled_window_new (winsize_h, winsize_v, table);
 
-  gtk_widget_set_size_request (scrolledwindow, winsize_h, winsize_v);
+  top_vbox = lives_vbox_new (FALSE, 0);
 
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_bg(gtk_bin_get_child (GTK_BIN (scrolledwindow)), GTK_STATE_NORMAL, &palette->normal_back);
-  }
-  
-  gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (scrolledwindow))),GTK_SHADOW_IN);
-
-  top_vbox = gtk_vbox_new (FALSE, 15);
-
-  gtk_box_pack_start (GTK_BOX (top_vbox), dummy_radio, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (top_vbox), scrolledwindow, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (top_vbox), dummy_radio, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (top_vbox), scrolledwindow, TRUE, TRUE, widget_opts.packing_height);
 
   gtk_container_add (GTK_CONTAINER (rte_window), top_vbox);
 
-  hbuttonbox = gtk_hbutton_box_new ();
-  gtk_box_pack_start (GTK_BOX (top_vbox), hbuttonbox, FALSE, TRUE, 20);
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
+  hbuttonbox = lives_hbutton_box_new ();
+  gtk_box_pack_start (GTK_BOX (top_vbox), hbuttonbox, FALSE, TRUE, widget_opts.packing_height*2);
 
   gtk_container_add (GTK_CONTAINER (hbuttonbox), clear_all_button);
   lives_widget_set_can_focus_and_default (clear_all_button);
@@ -2311,12 +2283,16 @@ GtkWidget * create_rte_window (void) {
   gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default (ok_button);
 
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
+#endif
+
 
   rtew_accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
   gtk_window_add_accel_group (GTK_WINDOW (rte_window), rtew_accel_group);
 
   gtk_widget_add_accelerator (ok_button, "activate", rtew_accel_group,
-                              GDK_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
 
   g_signal_connect (GTK_OBJECT (rte_window), "delete_event",
 		    G_CALLBACK (on_rtew_ok_clicked),
@@ -2353,11 +2329,16 @@ GtkWidget * create_rte_window (void) {
   if (prefs->open_maximised) {
     gtk_window_maximize (GTK_WINDOW(rte_window));
   }
+  lives_set_cursor_style(LIVES_CURSOR_NORMAL,NULL);
+  lives_set_cursor_style(LIVES_CURSOR_NORMAL,rte_window);
   return rte_window;
 }
 
 void refresh_rte_window (void) {
   if (rte_window!=NULL) {
+    lives_set_cursor_style(LIVES_CURSOR_BUSY,NULL);
+    lives_set_cursor_style(LIVES_CURSOR_BUSY,rte_window);
+    lives_widget_context_update();
     on_rtew_delete_event(NULL,NULL,NULL);
     rte_window=create_rte_window();
     gtk_widget_show (rte_window);
@@ -2378,7 +2359,7 @@ void on_assign_rte_keys_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 void rtew_set_keych (int key, boolean on) {
   g_signal_handler_block(key_checks[key],ch_fns[key]);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(key_checks[key]),on);
+  lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[key]),on);
   g_signal_handler_unblock(key_checks[key],ch_fns[key]);
 }
 
@@ -2386,11 +2367,11 @@ void rtew_set_keych (int key, boolean on) {
 void rtew_set_keygr (int key) {
   if (key>=0) {
     g_signal_handler_block(key_grabs[key],gr_fns[key]);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(key_grabs[key]),TRUE);
+    lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_grabs[key]),TRUE);
     g_signal_handler_unblock(key_grabs[key],gr_fns[key]);
   }
   else {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(dummy_radio),TRUE);
+    lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(dummy_radio),TRUE);
   }
 }
 
@@ -2418,7 +2399,7 @@ void redraw_pwindow (int key, int mode) {
     }
     if (rfx->is_template||(key==keyw&&mode==modew)) {
       // rip out the contents
-      if (mainw->invis==NULL) mainw->invis=gtk_vbox_new(FALSE,0);
+      if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
       child_list=gtk_container_get_children(GTK_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fx_dialog[1]))));
       action_area=lives_dialog_get_action_area(LIVES_DIALOG(fx_dialog[1]));
       gtk_container_set_focus_child(GTK_CONTAINER(action_area),NULL);
@@ -2607,7 +2588,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
     ninpar=num_in_params(filter,FALSE,FALSE);
     if (ninpar==0) xinp=NULL;
 
-    xinp=g_malloc((ninpar+1)*sizeof(weed_plant_t *));
+    xinp=(weed_plant_t **)g_malloc((ninpar+1)*sizeof(weed_plant_t *));
     x=0;
     for (i=poffset;i<poffset+ninpar;i++) xinp[x++]=inp[i];
     xinp[x]=NULL;
@@ -2662,7 +2643,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
 
   // redraw the window
 
-  if (mainw->invis==NULL) mainw->invis=gtk_vbox_new(FALSE,0);
+  if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
   child_list=gtk_container_get_children(GTK_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fxdialog))));
 
   action_area=lives_dialog_get_action_area(LIVES_DIALOG (fxdialog));
