@@ -21,13 +21,16 @@ static boolean prompt_existing_dir(gchar *dirname, guint64 freespace, boolean wr
 
   if (wrtable) {
     gchar *fspstr=lives_format_storage_space_string(freespace);
-    msg=g_strdup_printf(_("A directory named\n%s\nalready exists. Do you wish to use this directory ?\n\n(Free space = %s)\n"),dirname,fspstr);
+    msg=g_strdup_printf
+      (_("A directory named\n%s\nalready exists. Do you wish to use this directory ?\n\n(Free space = %s)\n"),dirname,fspstr);
     g_free(fspstr);
     res=do_yesno_dialog(msg);
   }
   else
     {
-      msg=g_strdup_printf(_("A directory named\n%s\nalready exists.\nLiVES could not write to this directory or read its free space.\nPlease select another location.\n"),dirname);
+      msg=g_strdup_printf
+	(_("A directory named\n%s\nalready exists.\nLiVES could not write to this directory or read its free space.\nPlease select another location.\n"),
+	 dirname);
       do_error_dialog(msg);
     }
   g_free(msg);
@@ -51,6 +54,7 @@ static boolean prompt_new_dir(gchar *dirname, guint64 freespace, boolean wrtable
     msg=g_strdup_printf(_("\nLiVES could not write to the directory\n%s\nPlease try again and choose a different location.\n"),dirname);
     do_error_dialog(msg);
   }
+
   g_free(msg);
   return res;
 }
@@ -201,8 +205,12 @@ static void on_init_aplayer_toggled (GtkToggleButton *tbutton, gpointer user_dat
 boolean do_audio_choice_dialog(short startup_phase) {
   GtkWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*radiobutton2,*radiobutton3,*label;
   GtkWidget *okbutton,*cancelbutton;
-  GtkWidget *eventbox,*hbox;
+  GtkWidget *hbox;
+
+  GtkAccelGroup *accel_group;
+
   GSList *radiobutton_group = NULL;
+
   gchar *txt0,*txt1,*txt2,*txt3,*txt4,*txt5,*txt6,*txt7,*msg;
 
   gint response;
@@ -266,17 +274,10 @@ boolean do_audio_choice_dialog(short startup_phase) {
   g_free(txt6);
   g_free(txt7);
 
-  dialog = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dialog), _("LiVES: - Choose an audio player"));
+  dialog = lives_standard_dialog_new (_("LiVES: - Choose an audio player"),FALSE);
 
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ALWAYS);
-  gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 200);
-
-  if (palette->style&STYLE_1) {
-    gtk_dialog_set_has_separator(GTK_DIALOG(dialog),FALSE);
-    gtk_widget_modify_bg(dialog, GTK_STATE_NORMAL, &palette->normal_back);
-  }
+  accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+  gtk_window_add_accel_group (GTK_WINDOW (dialog), accel_group);
 
   dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
   
@@ -285,169 +286,98 @@ boolean do_audio_choice_dialog(short startup_phase) {
   g_free(msg);
 
 
-  radiobutton0 = gtk_radio_button_new (NULL);
 
 #ifdef HAVE_PULSE_AUDIO
-  eventbox=gtk_event_box_new();
-  label=gtk_label_new_with_mnemonic ( _("Use _pulse audio player"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton0);
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    radiobutton0);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-
-  gtk_box_pack_start (GTK_BOX (hbox), radiobutton0, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
+  radiobutton0 = lives_standard_radio_button_new ( _("Use _pulse audio player"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
+  radiobutton_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton0));
 
   if (prefs->audio_player==-1) prefs->audio_player=AUD_PLAYER_PULSE;
 
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton0), radiobutton_group);
-  radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton0));
   if (prefs->audio_player==AUD_PLAYER_PULSE) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton0),TRUE);
     set_pref("audio_player","pulse");
   }
 
+  g_signal_connect (GTK_OBJECT (radiobutton0), "toggled",
+                      G_CALLBACK (on_init_aplayer_toggled),
+                      GINT_TO_POINTER(AUD_PLAYER_PULSE));
+
+
 #endif
 
-  radiobutton1 = gtk_radio_button_new(NULL);
+
 #ifdef ENABLE_JACK
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-  eventbox=gtk_event_box_new();
-  label=gtk_label_new_with_mnemonic ( _("Use _jack audio player"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton1);
+  radiobutton1 = lives_standard_radio_button_new(_("Use _jack audio player"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
+  radiobutton_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton1));
 
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    radiobutton1);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-
-  gtk_box_pack_start (GTK_BOX (hbox), radiobutton1, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-
-
-  if (prefs->audio_player==-1) prefs->audio_player=AUD_PLAYER_JACK;
-
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton1), radiobutton_group);
-  radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton1));
-
-  if (prefs->audio_player==AUD_PLAYER_JACK||!capable->has_pulse_audio) {
+  if (prefs->audio_player==AUD_PLAYER_JACK||!capable->has_pulse_audio||prefs->audio_player==-1) {
     prefs->audio_player=AUD_PLAYER_JACK;
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1),TRUE);
     set_pref("audio_player","jack");
   }
 
+  g_signal_connect (GTK_OBJECT (radiobutton1), "toggled",
+                      G_CALLBACK (on_init_aplayer_toggled),
+                      GINT_TO_POINTER(AUD_PLAYER_JACK));
+
 
 #endif
 
-  radiobutton2 = gtk_radio_button_new (NULL);
   if (capable->has_sox_play) {
+    hbox = lives_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-    eventbox=gtk_event_box_new();
-    label=gtk_label_new_with_mnemonic ( _("Use _sox audio player"));
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton2);
-    
-    gtk_container_add(GTK_CONTAINER(eventbox),label);
-    g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		      G_CALLBACK (label_act_toggle),
-		      radiobutton2);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-      gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-      gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-    }
-    
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-    
-    gtk_box_pack_start (GTK_BOX (hbox), radiobutton2, FALSE, FALSE, 10);
-    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
+    radiobutton2 = lives_standard_radio_button_new (_("Use _sox audio player"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
+    radiobutton_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton2));
 
     if (prefs->audio_player==-1) prefs->audio_player=AUD_PLAYER_SOX;
 
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton2), radiobutton_group);
-    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton2));
-
     if (prefs->audio_player==AUD_PLAYER_SOX) {
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton2),TRUE);
       set_pref("audio_player","sox");
     }
 
+    g_signal_connect (GTK_OBJECT (radiobutton2), "toggled",
+                      G_CALLBACK (on_init_aplayer_toggled),
+                      GINT_TO_POINTER(AUD_PLAYER_SOX));
+
 
   }
 
-  radiobutton3 = gtk_radio_button_new (NULL);
   if (capable->has_mplayer) {
-    eventbox=gtk_event_box_new();
-    label=gtk_label_new_with_mnemonic ( _("Use _mplayer audio player"));
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton3);
-    
-    gtk_container_add(GTK_CONTAINER(eventbox),label);
-    g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		      G_CALLBACK (label_act_toggle),
-		      radiobutton3);
-    if (palette->style&STYLE_1) {
-      gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-      gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-      gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-    }
-    
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-    
-    gtk_box_pack_start (GTK_BOX (hbox), radiobutton3, FALSE, FALSE, 10);
-    gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
+    hbox = lives_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+
+    radiobutton3 = lives_standard_radio_button_new (_("Use _mplayer audio player"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
 
     if (prefs->audio_player==-1) prefs->audio_player=AUD_PLAYER_MPLAYER;
 
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton3), radiobutton_group);
-    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton3));
-
     if (prefs->audio_player==AUD_PLAYER_MPLAYER) {
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton3),TRUE);
       set_pref("audio_player","mplayer");
     }
+						    
+    g_signal_connect (GTK_OBJECT (radiobutton3), "toggled",
+		      G_CALLBACK (on_init_aplayer_toggled),
+                      GINT_TO_POINTER(AUD_PLAYER_MPLAYER));
+
 
   }
 
 
-  g_signal_connect (GTK_OBJECT (radiobutton0), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
-                      GINT_TO_POINTER(AUD_PLAYER_PULSE));
-
-  g_signal_connect (GTK_OBJECT (radiobutton1), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
-                      GINT_TO_POINTER(AUD_PLAYER_JACK));
-
-  g_signal_connect (GTK_OBJECT (radiobutton2), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
-                      GINT_TO_POINTER(AUD_PLAYER_SOX));
-
-  g_signal_connect (GTK_OBJECT (radiobutton3), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
-                      GINT_TO_POINTER(AUD_PLAYER_MPLAYER));
-
   cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
   gtk_widget_show (cancelbutton);
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
 
+  gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+
   okbutton = gtk_button_new_from_stock ("gtk-go-forward");
   gtk_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
   gtk_widget_show (okbutton);
@@ -470,11 +400,11 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   if (prefs->audio_player==AUD_PLAYER_SOX||prefs->audio_player==AUD_PLAYER_MPLAYER) {
     gtk_widget_hide(mainw->vol_toolitem);
-    gtk_widget_hide(mainw->vol_label);
+    if (mainw->vol_label!=NULL) gtk_widget_hide(mainw->vol_label);
     gtk_widget_hide (mainw->recaudio_submenu);
   }
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
 
   return (response==GTK_RESPONSE_OK);
 }
@@ -487,7 +417,7 @@ static void add_test(GtkWidget *table, gint row, gchar *ttext, boolean noskip) {
   gtk_widget_show(label);
 
   if (!noskip) {
-    GtkWidget *image=gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_LARGE_TOOLBAR);
+    GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_REMOVE,LIVES_ICON_SIZE_LARGE_TOOLBAR);
     // TRANSLATORS - as in "skipped test"
     label=lives_standard_label_new(_("Skipped"));
 
@@ -498,14 +428,14 @@ static void add_test(GtkWidget *table, gint row, gchar *ttext, boolean noskip) {
     gtk_widget_show(image);
   }
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
 }
 
 
 static boolean pass_test(GtkWidget *table, gint row) {
   // TRANSLATORS - as in "passed test"
   GtkWidget *label=lives_standard_label_new(_("Passed"));
-  GtkWidget *image=gtk_image_new_from_stock(GTK_STOCK_APPLY,GTK_ICON_SIZE_LARGE_TOOLBAR);
+  GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_APPLY,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 
   gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
   gtk_widget_show(label);
@@ -513,14 +443,14 @@ static boolean pass_test(GtkWidget *table, gint row) {
   gtk_table_attach (GTK_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
   gtk_widget_show(image);
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
   return TRUE;
 }
 
 
 static boolean fail_test(GtkWidget *table, gint row, gchar *ftext) {
   GtkWidget *label;
-  GtkWidget *image=gtk_image_new_from_stock(GTK_STOCK_CANCEL,GTK_ICON_SIZE_LARGE_TOOLBAR);
+  GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_CANCEL,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 
   label=lives_standard_label_new(ftext);
 
@@ -536,7 +466,7 @@ static boolean fail_test(GtkWidget *table, gint row, gchar *ftext) {
   gtk_table_attach (GTK_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
   gtk_widget_show(image);
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
   
   return FALSE;
 }
@@ -557,23 +487,23 @@ boolean do_startup_tests(boolean tshoot) {
   GtkWidget *okbutton;
   GtkWidget *cancelbutton;
 
-  gchar *com,*rname,*afile,*tmp;
+  GtkAccelGroup *accel_group;
 
+  gchar *com,*rname,*afile,*tmp;
+  gchar *image_ext=g_strdup(prefs->image_ext);
+  gchar *title;
   guchar *abuff;
 
   size_t fsize;
 
   boolean success,success2,success3,success4;
+  boolean imgext_switched=FALSE;
 
   gint response,res;
   gint current_file=mainw->current_file;
 
   int out_fd,info_fd;
 
-  gchar *image_ext=g_strdup(prefs->image_ext);
-
-  boolean imgext_switched=FALSE;
-
   mainw->suppress_dprint=TRUE;
   mainw->cancelled=CANCEL_NONE;
 
@@ -585,23 +515,20 @@ boolean do_startup_tests(boolean tshoot) {
     mt_desensitise(mainw->multitrack);
   }
 
-  dialog = gtk_dialog_new ();
-
   if (!tshoot) {
-    gtk_window_set_title (GTK_WINDOW (dialog), _("LiVES: - Testing Configuration"));
+    title=g_strdup(_("LiVES: - Testing Configuration"));
   }
   else {
-    gtk_window_set_title (GTK_WINDOW (dialog), _("LiVES: - Troubleshoot"));
+    title=g_strdup(_("LiVES: - Troubleshoot"));
   }
 
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ALWAYS);
-  gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 200);
 
-  if (palette->style&STYLE_1) {
-    gtk_dialog_set_has_separator(GTK_DIALOG(dialog),FALSE);
-    gtk_widget_modify_bg(dialog, GTK_STATE_NORMAL, &palette->normal_back);
-  }
+  dialog = lives_standard_dialog_new (title,FALSE);
+
+  accel_group = GTK_ACCEL_GROUP(gtk_accel_group_new ());
+  gtk_window_add_accel_group (GTK_WINDOW (dialog), accel_group);
+
+  g_free(title);
 
   dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
 
@@ -612,6 +539,9 @@ boolean do_startup_tests(boolean tshoot) {
   gtk_widget_show (cancelbutton);
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
 
+  gtk_widget_add_accelerator (cancelbutton, "activate", accel_group,
+                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+
   if (!tshoot) {
     okbutton = gtk_button_new_from_stock ("gtk-go-forward");
     gtk_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
@@ -632,7 +562,7 @@ boolean do_startup_tests(boolean tshoot) {
 
   gtk_widget_show_all(dialog);
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
 
 
   // check for sox presence
@@ -710,7 +640,7 @@ boolean do_startup_tests(boolean tshoot) {
 
       while (mainw->cancelled==CANCEL_NONE&&(info_fd=open(cfile->info_file,O_RDONLY))==-1) {
 	g_usleep(prefs->sleep_time);
-	while (g_main_context_iteration(NULL,FALSE));
+	lives_widget_context_update();
       }
       
       if (info_fd!=-1) {
@@ -759,7 +689,7 @@ boolean do_startup_tests(boolean tshoot) {
 
     if (!success) {
       gtk_widget_destroy(dialog);
-      while (g_main_context_iteration(NULL,FALSE));
+      lives_widget_context_update();
       do_no_mplayer_sox_error();
       close_current_file(current_file);
       mainw->suppress_dprint=FALSE;
@@ -962,7 +892,7 @@ void do_startup_interface_query(void) {
 
   GtkWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*label;
   GtkWidget *okbutton;
-  GtkWidget *eventbox,*hbox;
+  GtkWidget *hbox;
   GSList *radiobutton_group = NULL;
   gchar *txt1,*txt2,*txt3,*msg;
 
@@ -978,17 +908,7 @@ void do_startup_interface_query(void) {
   g_free(txt2);
   g_free(txt3);
 
-  dialog = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dialog), _("LiVES: - Choose the startup interface"));
-
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ALWAYS);
-  gtk_window_set_default_size (GTK_WINDOW (dialog), 600, 200);
-
-  if (palette->style&STYLE_1) {
-    gtk_dialog_set_has_separator(GTK_DIALOG(dialog),FALSE);
-    gtk_widget_modify_bg(dialog, GTK_STATE_NORMAL, &palette->normal_back);
-  }
+  dialog = lives_standard_dialog_new (_("LiVES: - Choose the startup interface"),FALSE);
 
   dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
   
@@ -997,69 +917,22 @@ void do_startup_interface_query(void) {
   g_free(msg);
 
 
-  radiobutton0 = gtk_radio_button_new (NULL);
-
-
-  eventbox=gtk_event_box_new();
-  label=gtk_label_new_with_mnemonic ( _("Start in _Clip Edit mode"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton0);
-
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    radiobutton0);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-
-  gtk_box_pack_start (GTK_BOX (hbox), radiobutton0, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
-
-
-
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton0), radiobutton_group);
-  radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton0));
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+  radiobutton0 = lives_standard_radio_button_new (_("Start in _Clip Edit mode"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
+  radiobutton_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (radiobutton0));
 
   label=lives_standard_label_new(_("This is the best choice for simple editing tasks and for VJs\n"));
 
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, 10);
-
-  radiobutton1 = gtk_radio_button_new(NULL);
-
-
-  eventbox=gtk_event_box_new();
-  label=gtk_label_new_with_mnemonic ( _("Start in _Multitrack mode"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), radiobutton1);
-
-  gtk_container_add(GTK_CONTAINER(eventbox),label);
-  g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		    G_CALLBACK (label_act_toggle),
-		    radiobutton1);
-  if (palette->style&STYLE_1) {
-    gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_fg(eventbox, GTK_STATE_NORMAL, &palette->normal_fore);
-    gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL, &palette->normal_back);
-  }
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 10);
-
-  gtk_box_pack_start (GTK_BOX (hbox), radiobutton1, FALSE, FALSE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, 10);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, widget_opts.packing_height);
 
+  hbox = lives_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+  radiobutton1 = lives_standard_radio_button_new (_("Start in _Multitrack mode"),TRUE,radiobutton_group,LIVES_BOX(hbox),NULL);
 
   label=lives_standard_label_new(_("This is a better choice for complex editing tasks involving multiple clips.\n"));
 
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, 10);
-
-
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton1), radiobutton_group);
-  radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton1));
+  gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, widget_opts.packing_height);
 
   if (prefs->startup_interface==STARTUP_MT) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1),TRUE);
@@ -1067,6 +940,7 @@ void do_startup_interface_query(void) {
 
   okbutton = gtk_button_new_from_stock ("gtk-go-forward");
   gtk_button_set_label(GTK_BUTTON(okbutton),_("_Finish"));
+
   gtk_widget_show (okbutton);
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
@@ -1086,7 +960,7 @@ void do_startup_interface_query(void) {
 
   gtk_widget_destroy(dialog);
 
-  while (g_main_context_iteration(NULL,FALSE));
+  lives_widget_context_update();
 
 }
 
